      SUBROUTINE FFPATI(XC,BLOCK,XB,THETA,PHI,ETHETA,EPHI)
C
C  Far field pattern from currents in common for image in gr.pl.
C  with dielectric slab to top surface at Z = 0
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  THETA     Angle from Z axis (boresight) (radians)
C  PHI       Spherical angle from X-axis (radians)
C  ETHETA    Electric field in Theta direction
C  EPHI      Electric field in Phi direction
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
      COMMON /DIELECT/ERS,THS,URS,ITEM
C
C  Dielectric slab common: /DIELECT/
C  ERS	  Dielectric constant
C	  ER*cmplx(1.,-(loss tangent)) or
C	  cmplx(ER,-(conductivity(S/m))/(2*pi*8.854185e-12*frequency))
C  THS	  Thickness (m)
C  URS	  Relative permeability
C  ITEM   If 1, use TEM approximation
C
      COMPLEX CURJA,CURMA,ETHETA,EPHI,CURJ(3),CURM(3),ETH,EPH,CONJ
     1,ZSTM,ZSTE,GTM,GTE,ERS,PZM,ZMTE,ZMTM
      DIMENSION VR(3),VT(3),VP(3),XS(3),XC(3),XB(1)
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,ZS/376.73/
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
C ------------- -j*2*Pi*Frequency*Mu
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
      ETHETA=0.
      EPHI=0.
      DO 2 I=1,NCUR
      DO 1 J=1,3
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    1 CURM(J)=CURMA(J,I)
      XS(3)=-XS(3)
      IF(BLOCK(XB,XS,VR).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJF(VR,VT,VP,XS,PKC,CURJ,ETH,EPH)
      ETHETA=ETHETA+ETH*CONJ
      EPHI=EPHI+EPH*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGRHJF(VR,VT,VP,XS,PKC,CURM,ETH,EPH)
      ETHETA=ETHETA-ETH
      EPHI=EPHI-EPH
      ENDIF
      ENDIF
    2 CONTINUE
C --------- Incident wave impedances
      ZTM=ZS*VR(3)
      ZTE=ZS/VR(3)
      PZM=PKC*CSQRT((ERS*URS-1.)+VR(3)**2)
      ZMTM=ZS*PZM/PKC/ERS
      ZMTE=ZS*PKC*URS/PZM
      IF(ITEM.EQ.1)THEN
      ZSTM=ZS*CSIN(PKC*THS*CSQRT(ERS))/CCOS(PKC*THS*CSQRT(ERS))*
     1 CMPLX(0.,-1.)/CSQRT(ERS)
      ZSTE=ZSTM
      ELSE IF(ITEM.EQ.-1)THEN
      ZSTM=ZMTM*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ZSTE=ZMTE*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ELSE IF(ITEM.EQ.0)THEN
      ZSTM=ZMTM
      ZSTE=ZMTE
      ENDIF
C --------- Find the reflection coefficients of two polarizations
      GTM=(ZTM-ZSTM)/(ZTM+ZSTM)
      GTE=(ZSTE-ZTE)/(ZSTE+ZTE)
C --------- Reduce reflected fields
      ETHETA=-ETHETA*GTM
      EPHI=EPHI*GTE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
