      SUBROUTINE NRPATR(XC,BLOCK,XB,XF,EFIELD,HFIELD)
C
C  Radiative Near field pattern from currents in common
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  XF        Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM
      DIMENSION XS(3),XF(3),XC(3),XB(1)
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PKC*CC*EPS)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 7 I=1,NCUR
      DO 2 J=1,3
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    2 CURM(J)=CURMA(J,I)
C --------- Check for ray blockage
      IF(BLOCK(XB,XS,XF).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJN(XF,XS,PKC,CURJ,EF)
      DO 3 J=1,3
    3 EFIELD(J)=EFIELD(J)+EF(J)*CONJ
      CALL VGRHJN(XF,XS,PKC,CURJ,HF)
      DO 4 J=1,3
    4 HFIELD(J)=HFIELD(J)+HF(J)
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGREJN(XF,XS,PKC,CURM,HF)
      DO 5 J=1,3
    5 HFIELD(J)=HFIELD(J)+HF(J)*CONM
      CALL VGRHJN(XF,XS,PKC,CURM,EF)
      DO 6 J=1,3
    6 EFIELD(J)=EFIELD(J)-EF(J)
      ENDIF
      ENDIF
    7 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
