      SUBROUTINE PATINF(LUNIT,INST,THETA,PHI,ET,EP)
C
C  Interpolation from multiple patterns
C  using bilinear interpolation from file with Theta & Phi components
C  This routine requires static storage
C  It can use multiple files if they have the same structure and use
C  the same multipliers
C
C  INST    - 1 Initialize:
C            2 Return pattern value
C  THETA       Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  PHI         Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  ET          Complex electric field V/m @ 1 m, 1 w input Theta
C  EP          Complex electric field V/m @ 1 m, 1 w input Phi
C
      DIMENSION SP(3),SR(3)
      INTEGER*4 IBUF(4)
      COMPLEX ET,EP,Y(4),X(4)
      DATA TR/.01745329/,GCONS/.1826374/
      IF(INST.LT.2)THEN
C
C  Reads random access data file LU = LUNIT, open before calling
C
C ------- Initialize
C  1st record:
C  Type: [1 Conic, 2 Great Circle], # Scans, # Points in scan
C  Type = -2 if Theta > 180 or Theta < 0 included
C
C  2nd record:  Step angles: Start, Step; Scan angles: Start, Step
C  3rd record & following: Theta, Phi Components (Complex voltages)
C
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,4)
      ITYPE=IBUF(1)
      NSCAN=IBUF(2)
      NPOINT=IBUF(3)
      READ(LUNIT,REC=2)STS,STP,SCS,SCP
      VT=10.**(THETA/20.)/GCONS
      VP=10.**(PHI/20.)/GCONS
      ELSE
C -------- Return value
      SP(1)=1.
      SP(2)=TR*THETA
      SP(3)=TR*PHI
C -------- Convert to rectangular and back to spherical
      CALL ARADS(SP,SR)
      CALL RETSP(SR,SP)
      IF(ITYPE.EQ.1)THEN
C -------- Conical patterns
      THH=SP(2)/TR
      PHH=SP(3)/TR
      ELSE
C -------- Great circle patterns
      THH=SP(3)/TR
      PHH=SP(2)/TR
      IF(THH.LT.0..AND.ITYPE.EQ.-2)THEN
      PHH=360.-PHH
      THH=180.+THH
      ENDIF
      ENDIF
      IF(ITYPE.NE.2)NM=360./SCP+.1
      IF(ITYPE.EQ.2)NM=180./SCP+.1
      DSC=PHH-SCS
      IF(ITYPE.NE.2)DSC=AMOD(DSC,360.)
      IF(ITYPE.EQ.2.AND.ABS(DSC-180.).GT..02)DSC=AMOD(DSC,180.)
      DSC=DSC/SCP
      IF(DSC.LT.0.)DSC=DSC+NM
      NP=DSC
      T=DSC-NP
      NP=NP+1
      IF(NP.EQ.NM)THEN
      NP=NP-1
      T=T+1
      ENDIF
      IF(ITYPE.EQ.2)NM=360./STP+.1
      IF(ITYPE.NE.2)NM=180./STP+.1
      DST=THH-STS
      IF(ITYPE.EQ.2)DST=AMOD(DST,360.)
      IF(ITYPE.NE.2.AND.ABS(DST-180.).GT..02)DST=AMOD(DST,180.)
      DST=DST/STP
      IF(DST.LT.0.)DST=DST+NM
      NT=DST
      U=DST-NT
      NT=NT+1
      IF(ITYPE.EQ.1)TIN=STS+(NT-1)*STP
      IF(IABS(ITYPE).EQ.2)TIN=SCS+(NP-1)*SCP
      SGN=SIGN(1.,SIN(TIN*TR))
      DO 3 I=1,4
      Y(I)=0.
    3 X(I)=0.
C -------- Pick points for bilinear interpolation
      IF(NP.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+(NT-1)*NPOINT+2
      READ(LUNIT,REC=NN)Y(1),X(1)
      IF(NP+1.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+1+(NT-1)*NPOINT+2
      READ(LUNIT,REC=NN)Y(2),X(2)
      ENDIF
      ENDIF
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+NT*NPOINT+2
      READ(LUNIT,REC=NN)Y(4),X(4)
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+1+NT*NPOINT+2
      READ(LUNIT,REC=NN)Y(3),X(3)
      ENDIF
      ENDIF
      ET=((1.-T)*(1.-U)*Y(1)+T*(1.-U)*Y(2)+T*U*Y(3)+(1.-T)*U*Y(4))*VT
      EP=((1.-T)*(1.-U)*X(1)+T*(1.-U)*X(2)+T*U*X(3)+(1.-T)*U*X(4))*VP
      ET=ET*SGN
      EP=EP*SGN
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
