% MATLAB script file for calculating far-field 
% pattern of vector electric point source

lam=1;			% wavelength
k0=2*pi/lam;		% wavenumber
Z0=376.7;		% free-space impedance

rs=[0 0 0];		% position vector

J0=lam*sqrt(3/376.7/pi); % electric source current 
			% density, Amp-inch
Js=J0.*[1 0 0];		% electric current density

Nf=101;			% number of field points
th1=0;			% pattrn start theta angle
th2=pi;			% pattern end theta angle
nf=(1:Nf)';		% field point index
dth=(th2-th1)/(Nf-1);	% theta increment
th=th1+dth*(nf-1);	% theta, radians
thd=th*180/pi;		% theta, deg
ph=0*pi/2*ones(Nf,1);	% phi angles

Hf=-propff01(rs,Js,th,ph,k0); 	% H field 
Ef=Z0*[Hf(:,2) -Hf(:,1)];	% E field 

ru=[cos(ph).*sin(th) sin(ph).*sin(th) cos(th)];
		% unit vector in far-field direction

PthdB=10*log10(abs(4*pi/Z0/2*Ef(:,1).^2));
PphdB=10*log10(abs(-4*pi/Z0/2*Ef(:,2).^2));

plot(thd,PthdB);grid;axis([0 180 -30 10])


%