% MATLAB script file for calculating far-field
% patterns of pyramidal horn
%
% PART c: aperture currents
%

Lx=wx/2/tan(pi/180*thxd/2);	% x-z plane length
Ly=wy/2/tan(pi/180*thyd/2);	% y-z plane length
phA=-k0*(sqrt(xp.^2+Lx^2)+sqrt(yp.^2+Ly^2)-Lx-Ly);
			% aperture relative phase curvature 

Ix=ones(size(xp));	% Ns by 1 array of ones
I13=ones(1,3);		% 1 by 3 array of ones

kTEx=mTEx*pi/wx;	% cutoff x wavenumbers of TE modes
kTEy=mTEy*pi/wy;	% cutoff y wavenumbers of TE modes
kTMx=mTMx*pi/wx;	% cutoff x wavenumbers of TM modes
kTMy=mTMy*pi/wy;	% cutoff y wavenumbers of TM modes

kTEc=sqrt(kTEx.^2+kTEy.^2);	% cutoff TE wavenumbers
kTMc=sqrt(kTMx.^2+kTMy.^2);	% cutoff TM wavenumbers
kTEz=sqrt(k0^2-kTEc.^2);	% TE guided wavenumbers
kTMz=sqrt(k0^2-kTMc.^2);	% TM guided wavenumbers

YTM=kTMz/k0/Z0;	% TM mode impedances
ZTE=Z0*kTEz/k0;	% TE mode impedances

cxTM=cos(xp*kTMx);	% Ns by NTM arrays
sxTM=sin(xp*kTMx);
cyTM=cos(yp*kTMy);
syTM=sin(yp*kTMy);

cxTE=cos(xp*kTEx);	% Ns by NTE arrays
sxTE=sin(xp*kTEx);
cyTE=cos(yp*kTEy);
syTE=sin(yp*kTEy);

dxTE=.5*(1-(-1).^mTEx);	% 1 if mTEx element is even mode
dyTE=.5*(1-(-1).^mTEy);	% 1 if mTEy element is even mode
dxTM=.5*(1-(-1).^mTMx);	% 1 if mTMx element is even mode
dyTM=.5*(1-(-1).^mTMy);	% 1 if mTMy element is even mode

% mode functions:

pxTM=(Ix*dxTM).*cxTM+(1-Ix*dxTM).*sxTM;
pyTM=(Ix*dyTM).*cyTM+(1-Ix*dyTM).*syTM;
qxTM=-(Ix*dxTM).*sxTM+(1-Ix*dxTM).*cxTM;
qyTM=-(Ix*dyTM).*syTM+(1-Ix*dyTM).*cyTM;

pxTE=(Ix*dxTE).*sxTE-(1-Ix*dxTE).*cxTE;
pyTE=(Ix*dyTE).*syTE-(1-Ix*dyTE).*cyTE;
qxTE=(Ix*dxTE).*cxTE+(1-Ix*dxTE).*sxTE;
qyTE=(Ix*dyTE).*cyTE+(1-Ix*dyTE).*syTE;		

% aperture fields, Ns by (length of m) arrays:

HTMxp=-i*(Ix*(YTM.*VTM.*kTMy)).*pxTM.*qyTM;
HTMyp=i*(Ix*(YTM.*VTM.*kTMx)).*qxTM.*pyTM;
ETMxp=i*(Ix*(VTM.*kTMx)).*qxTM.*pyTM;
ETMyp=i*(Ix*(VTM.*kTMy)).*pxTM.*qyTM;

ETExp=i*(Ix*(ZTE.*ITE.*kTEy)).*pxTE.*qyTE;
ETEyp=-i*(Ix*(ZTE.*ITE.*kTEx)).*qxTE.*pyTE;
HTExp=i*(Ix*(ITE.*kTEx)).*qxTE.*pyTE;
HTEyp=i*(Ix*(ITE.*kTEy)).*pxTE.*qyTE;

if(length(VTM)>1);	% total fields (sum modes)
  ETMx=sum(ETMxp.').';
  ETMy=sum(ETMyp.').';
  HTMx=sum(HTMxp.').';
  HTMy=sum(HTMyp.').';
else
  ETMx=ETMxp;ETMy=ETMyp;HTMx=HTMxp;HTMy=HTMyp;
end

if(length(ITE)>1)
  ETEx=sum(ETExp.').';	
  ETEy=sum(ETEyp.').';
  HTEx=sum(HTExp.').';
  HTEy=sum(HTEyp.').';
else
  ETEx=ETExp;ETEy=ETEyp;HTEx=HTExp;HTEy=HTEyp;
end

% Ns by 3 arrays, aperture vector fields:

ETM=(ETMx*I13).*u1+(ETMy*I13).*u2;
HTM=(HTMx*I13).*u1+(HTMy*I13).*u2;
ETE=(ETEx*I13).*u1+(ETEy*I13).*u2;
HTE=(HTEx*I13).*u1+(HTEy*I13).*u2;

Ea=ETM+ETE;	% total aperture fields
Ha=HTM+HTE;	

Ma=cross01(un,Ea).*exp(-i*phA*I13);	% aperture mag currents
Ja=-cross01(un,Ha).*exp(-i*phA*I13);	% aperture elec currents

Pm=1/2/Z0*sum(abs(dot01(Ma,Ma'.')).*dS);	% power
Pe=1/2*Z0*sum(abs(dot01(Ja,Ja'.')).*dS);

Ms=Ma/sqrt(Pm).*(dS*ones(1,3));	% current in Volt*meter
Js=Ja/sqrt(Pe).*(dS*ones(1,3));	% current in Amp*meter

%