% MATLAB script file for calculating far-field 
% patterns of open-ended waveguide
% 
% PART d: calculates the radiation patterns
% Expected previous files: po7a, po07b, po07c
%

nth=(1:Nth)';			% theta pattern index array
dthd=(thd2-thd1)/(Nth-1);	% theta increment
phpat=phd*pi/180;		% phi angle of theta cut, radians
thd=thd1+(nth-1)*dthd;		% Nth by 1 array of theta angles
thp=pi/180*thd;			% in degrees
php=phpat*ones(Nth,1);		% Nth by 1 array, phi angles

EM=propff01(rs,Ms,thp,php,k0); 	% FF electric field from Mn
HJ=-propff01(rs,Js,thp,php,k0);	% FF magnetic field from Jn

Eth=EM(:,1)+HJ(:,2)*Z0;		% theta electric fields
Eph=EM(:,2)-HJ(:,1)*Z0;		% phi electric fields
Er=1/sqrt(2)*(Eth+i*Eph);	% RHCP voltage
El=1/sqrt(2)*(Eth-i*Eph);	% LHCP voltage

Pth=abs(4*pi/2/Z0*(Eth).^2);
Pph=abs(4*pi/2/Z0*(Eph).^2);
PthdB=10*log10(Pth);
PphdB=10*log10(Pph);

Pr=abs(4*pi/2/Z0*Er.^2);
Pl=abs(4*pi/2/Z0*El.^2);
PrdB=10*log10(Pr);
PldB=10*log10(Pl);

%

