% MATLAB script file for calculating far-field 
% patterns of conical corrugated horn
% 
% PART b: feed aperture surface
%

Nar=ceil(Da/2/drm);	% number of radial samples
dar=Da/2/Nar;		% actual sampling increment

ra=zeros(Nar,1);	% memory pre-allocation
Nac=ra;

Na=0;			% counter zero
for nar=1:Nar		% iterate over radius
  ra(nar)=(nar-.5)*dar;		% phi-sampling radii
  Nac(nar)=ceil(2*pi*ra(nar)/dphm);
			% array of numbers of circ. samps 
  Na=Na+Nac(nar);	% total number of aperture samples
end

uns=ones(Na,1)*un0; 	% unit normals	
ut2=ones(Na,1)*unitr(crossr(un0,[1 0 0]));
			% second surf. tangent
ut1=crossr(ut2,un0);	% first surface unit tangent 

dap=2*pi./Nac;
	% array of actual sample phi spacings at each radius

raP=[];		% initialize arrays
DSa=[];
phaP=[];
 
for nar=1:Nar		% iterate over radius
  if(nar/20==ceil(nar/20));[nar Nar],end
  phP=((1:Nac(nar))'-.5)*dap(nar); 
			% phi primed angles array
  phaP=[phaP;phP];	% array of all phi primed angles  
  raP=[raP;ra(nar)*[cos(phP) sin(phP)]];  
			% array of primed position vectors
  DSa=[DSa;ra(nar)*dap(nar)*dar*ones(size(phP))];	
			% array of sample areas
end

rs=ones(Na,1)*r0+ut1.*(raP(:,1)*ones(1,3))...
	+ut2.*(raP(:,2)*ones(1,3));  % position vectors
rho=sqrt(raP(:,1).^2+raP(:,2).^2);	% rho
phi=atan2(raP(:,2),raP(:,1));		% phi
 
urs=unitr([rs zeros(Na,1)]);	% array of radial unit vectors
ups=crossr(uns,urs);	% array of circumferential unit vectors

%