% MATLAB script file for calculating far-field 
% patterns of reflector including blockage
% 
% PART a: define variables
%

lam=1;		% wavelength
k0=2*pi/lam;	% wavenumber
Z0=376.7;	% free-space characteristic impedance


%____corrugated horn parameters

r0=[0 0 -.05*lam];	% aperture center position vector

un0=[0 0 -1];		% unit normal of aperture
ut2=[0 1 0];		% unit vector in aperture y dimension
ut1=cross01(ut2,un0);	% unit vector in apertue x dimension

Da=1.07*lam;	% feed aperture diameter, inches
thfd=60;	% feed conical flare angle, deg

Xs=1e30;	% corrugation reactance

nph=1;		% phi mode number
krh1=0;		% start value, search for rho wavenumber
krh2=7;	% stop value, search for rho wavenumber
Nkrh=1000;	% number of rho wavenumber steps 

Ap=1;		% TM sine mode
Bp=i;		% TM cosine mode

dphm=.25*lam;	% x maximum sampling spacing
drm=.25*lam;	% y maximum sampling spacing


%____reflector parameters

Darx=20*lam;	% elliptical aperture x dimension, inches
Dary=20*lam;	% elliptical aperture y dimension, inches
Fl=10*lam;	% parab focal length, inch
xa0=0;		% aperture center x location, inch
ya0=0;		% aperture center y location, inch
zv0=-Fl;	% paraboloid vertex z location, inch

drxmax=.65*lam;	% max allowed x sampling spacing
drymax=.65*lam;	% max allowed y sampling spacing


%____pattern angles

thd1=-30;	% theta cut start angle, deg
thd2=30;	% theta stop angle, deg
Nth=201;	% number of theta angles
Nthg=10;	% number of simultaneous angles
phd=0;		% phi angle for theta cut


%____feed blockage: circular disk in x-y plane

Dfb=Darx/10;	% feed disk dia, inches
xbf0=0;		% feed disk center, inches
ybf0=0;
zbf0=0;

drbfmax=.5*lam;		% maximum rho sample
dpbfmax=.5*lam;		% maximum phi sample 
 

%____strut blockage:  

% struts are modelled as flat strips running from
% edge of feed blockage disk to edge of reflector  

Wbs=.5*lam;	% strut width (in phi dir), inches

% strut attachment points, feed blockage disk:
xybaf=[	Dfb/2		0		
	-.5*Dfb/2	 .866*Dfb/2	
	-.5*Dfb/2	-.866*Dfb/2	];	% x, y
zbaf=zeros(3,1);				% z 
rbaf=[xybaf zbaf];

% strut attachment point, reflector disk:
xybar=[	Darx/2		0		 
	-.5*Darx/2	 .866*Dary/2
	-.5*Darx/2	-.866*Dary/2	]; 	% x, y
zbar=(xybar(:,1).^2+xybar(:,2).^2)/4/Fl+zv0;	% z
rbar=[xybar zbar];

dwbsmax=.4*lam; % max width sampling, strut
dlbsmax=.4*lam; % max length sampling 


I13=ones(1,3); % 1 by 3 array of ones

%