% MATLAB script file for calculating far-field 
% patterns of reflector including blockage
% 
% PART d: calculate feed and strut blockage
%

%____feed disk blockage geometry

rbf0=[xbf0 ybf0 zbf0];	% feed-horn aperture center 
Nbfr=ceil(Dfb/2/drbfmax); % number of radial samples
dbfr=Dfb/2/Nbfr;	% radial sampling increment

rbf=zeros(Nbfr,1);	% memory pre-allocation
Nbfc=rbf;

Nbf=0;				% counter zero
for nbfr=1:Nbfr			% iterate over radius
  rbfr(nbfr)=(nbfr-.5)*dbfr;	% radii
  Nbfc(nbfr)=ceil(pi*2*rbfr(nbfr)/dpbfmax);   
				% phi samples 
  Nbf=Nbf+Nbfc(nbfr);		
			% total number of samples
end

unbf=ones(Nbf,1)*[0 0 1]; 	% unit normals
u2bf=unitr(cross01(unbf,[1 0 0]));  % second unit tan
u1bf=cross01(u2bf,unbf);		% first unit tan 

dbfp=pi*2./Nbfc;	% array of phi spacings at each radius

phibfP=[];
DSbf=[];
rbfP=[];
 
for nbfr=1:Nbfr		% iterate over radius
  if(nbfr/20==ceil(nbfr/20));[nbfr Nbfr],end
  phbfP=((1:Nbfc(nbfr))'-.5)*dbfp(nbfr);  
  phibfP=[phibfP;phbfP];	% rel phi angles  
  rbfP=[rbfP;rbfr(nbfr)*[cos(phbfP) sin(phbfP)]];  
		% primed pos vectors
  DSbf=[DSbf;rbfr(nbfr)*dbfp(nbfr)*dbfr*ones(Nbfc(nbfr),1)];
		% array of sample areas
end

rbf=ones(Nbf,1)*rbf0+u1bf.*(rbfP(:,1)*ones(1,3))...
	+u2bf.*(rbfP(:,2)*ones(1,3));  % pos vectors 
urbf=norm01([rbf(:,1:2) zeros(Nbf,1)]);	% radial unit vectors
upbf=cross01(unbf,urbf);		% circ unit vectors


%____feed strut blockage geometry

rlbsc=rbar-rbaf;		% strut axes
lbs=length01(rlbsc);	% strut lengths
u1bsc=norm01(rlbsc); % first tan unit vectors, struts

Nstrut=length(rbaf(:,1));	% number of struts
u2bsc=-norm01(cross01(u1bsc,ones(Nstrut,1)*[0 0 1]));  
		% second tangent unit vectors,struts
unbsc=cross01(u1bsc,u2bsc);	% unit normals

Nbsw=ceil(Wbs*ones(Nstrut,1)/dwbsmax)+1;  
			% numbers of width samples
Nbsl=ceil(lbs/dlbsmax)+1; % numbers of length samples

Nbs=Nbsl.*Nbsw;	% numbers of total samples per strut
Nbstot=sum(Nbs); % total number of samples, struts

dbsw=Wbs./(Nbsw-1);	% width sampling increments
dbsl=lbs./Nbsl;		% length sampling increments

rbs0=rbaf-Wbs/2.*u2bsc+(dbsl/2*I13).*u1bsc;		
		% sampling starting point v

rbs=[];			% initialize arrays
unbs=[];
u1bs=[];
u2bs=[];
DSbs=[];

for n=1:Nstrut;		% iterate over strut 
  [n Nstrut]

  un=ones(Nbs(n),1)*unbsc(n,:); 		
		% Nbs by 3 array, unit normals
  u1=ones(Nbs(n),1)*u1bsc(n,:);		
		% Nbs by 3 array, first surface tangent
  u2=ones(Nbs(n),1)*u2bsc(n,:);		
		% Nbs by 3 array, second surface tangent

  lsc=(0:Nbsl(n)-1)'*dbsl(n);		
		% Nbsl by 1 array, length coordinates
  wsc=(0:Nbsw(n)-1)*dbsw(n);		
		% 1 by Nbsw array, width coordinates
  
  ls=reshape(lsc*ones(size(wsc)),Nbs(n),1);	
		% Nbs by 1 array, length coordinates
  ws=reshape(ones(size(lsc))*wsc,Nbs(n),1);	
		% Nbs by 1 array, width coordinates

  rstr=ones(Nbs(n),1)*rbs0(n,:)...
	+(ls*I13).*u1+(ws*I13).*u2;
  rbs=[rbs;rstr]; 	% samp pos vects


  unbs=[unbs;un];			
  u1bs=[u1bs;u1];
  u2bs=[u2bs;u2];

  DSbs=[DSbs;dbsl(n)*dbsw(n)*ones(Nbs(n),1)];	
			% surface area increments

end

Nb=Nbf+Nbstot;	% total strut and feed blockage samples
rb=[rbf;rbs]; % combined blockage sample position vectors
unb=[unbf;unbs]; % combined normal unit vectors
DS=[DSbf;DSbs];	% combined sample areas

%