% MATLAB script file for calculating monostatic RCS of Truncated
% Right-Circular Cone
%
% PART b: conical target definition
%

%____bottom cap

rc10=[0 0 0];	% bottom cap center location
Nbc1=ceil(Rc1/dc1max); 	% number of radial samples
dc1=Rc1/Nbc1;		% radial sampling increment

rc1=zeros(Nbc1,1);	% memory pre-allocation
Nac1=rc1;

Nc1=0;				% counter zero
for nc1=1:Nbc1			% iterate over radius
  rc1(nc1)=(nc1-.5)*dc1;	% radii
  Nac1(nc1)=ceil(pi*2*rc1(nc1)/dc1max); % phi samples 
  Nc1=Nc1+Nac1(nc1);		% total number of samples
end

unc1=ones(Nc1,1)*[0 0 -1]; 		% unit normals
u2c1=unitr(cross01(unc1,[1 0 0]));  	% second unit tan
u1c1=cross01(u2c1,unc1);		% first unit tan 

dc1p=pi*2../Nac1;	% array of phi spacings at each radius

phic1P=[];
DSc1=[];
rc1P=[];
 
for nc1=1:Nbc1		% iterate over radius
  if(nc1/20==ceil(nc1/20));[nc1 Nbc1],end
  phc1P=((1:Nac1(nc1))'-.5)*dc1p(nc1);  
  phic1P=[phic1P;phc1P];	% rel phi angles  
  rc1P=[rc1P;rc1(nc1)*[cos(phc1P) sin(phc1P)]];  
		% primed pos vectors
  DSc1=[DSc1;rc1(nc1)*dc1p(nc1)*dc1*ones(Nac1(nc1),1)];
		% array of sample areas
end

r1=ones(Nc1,1)*rc10+u1c1.*(rc1P(:,1)*ones(1,3))...
	+u2c1.*(rc1P(:,2)*ones(1,3));  % pos vectors 


%____top cap

rc20=[0 0 Lcc];	% top cap center location
Nbc2=ceil(Rc2/dc2max); 	% number of radial samples
dc2=Rc2/Nbc2;		% radial sampling increment

rc2=zeros(Nbc2,1);	% memory pre-allocation
Nac2=rc2;

Nc2=0;				% counter zero
for nc2=1:Nbc2			% iterate over radius
  rc2(nc2)=(nc2-.5)*dc2;	% radii
  Nac2(nc2)=ceil(pi*2*rc2(nc2)/dc2max); % phi samples 
  Nc2=Nc2+Nac2(nc2);		% total number of samples
end

unc2=ones(Nc2,1)*[0 0 1]; 		% unit normals
u2c2=unitr(cross01(unc2,[1 0 0]));  	% second unit tan
u1c2=cross01(u2c2,unc2);		% first unit tan 

dc2p=pi*2../Nac2;	% array of phi spacings at each radius

phic2P=[];
DSc2=[];
rc2P=[];
 
for nc2=1:Nbc2		% iterate over radius
  if(nc2/20==ceil(nc2/20));[nc2 Nbc2],end
  phc2P=((1:Nac2(nc2))'-.5)*dc2p(nc2);  
  phic2P=[phic2P;phc2P];	% rel phi angles  
  rc2P=[rc2P;rc2(nc2)*[cos(phc2P) sin(phc2P)]];  
		% primed pos vectors
  DSc2=[DSc2;rc2(nc2)*dc2p(nc2)*dc2*ones(Nac2(nc2),1)];
		% array of sample areas
end

r2=ones(Nc2,1)*rc20+u1c2.*(rc2P(:,1)*ones(1,3))...
	+u2c2.*(rc2P(:,2)*ones(1,3));  % pos vectors 


%____conical surface

Nbcl=ceil(Lcc/dczmax+1); 	% number of length samples
dcl=Lcc/Nbcl;			% length sampling increment
nncl=(1:Nbcl)';			% array of length indices
zcl=(nncl-.5)*dcl;		% z positions
Lcone=Rc1*Lcc/(Rc1-Rc2);	% base to apex dimension
rcl=Rc1/Lcone*(Lcone-zcl);	% radii
alch=atan(Rc1/Lcone);	% cone half angle, rad

Nacl=ceil(pi*2*rcl/dczmax+1); % array of numbers of phi samples 
Ncl=sum(Nacl);	% total number of samples

dclp=pi*2../Nacl;	% array of phi spacings, rad
phiclP=[];
DScl=[];
rclP=[];
zclP=[];
 
for ncl=1:Nbcl		% iterate over z

  if(ncl/20==ceil(ncl/20));[ncl Nbcl],end	% iteration

  phclP=((1:Nacl(ncl))'-.5)*dclp(ncl);  % phi angles at z
  phiclP=[phiclP;phclP];		% array of phi angles  

  rclP=[rclP;rcl(ncl)*[cos(phclP) sin(phclP)]];  
				% primed radial pos vectors
  zclP=[zclP;zcl(ncl)*ones(Nacl(ncl),1)];	% array of z
  DSclz=dcl*dclp(ncl)*Rc1...
	/Lcone*sqrt((Rc1/Lcone)^2+1)*(Lcone-zcl(ncl));
  DScl=[DScl;DSclz*ones(Nacl(ncl),1)];	% array of sample areas 

end

urhlP=[cos(phiclP) sin(phiclP)];	% rho unit vector
uncl=[urhlP*cos(alch) sin(alch)*ones(Ncl,1)];	% unit normals


rl=[rclP zclP]; 	% pos vectors 


%____total surface

DSc=[DSc1;DSc2;DScl];	% sample areas
unc=[unc1;unc2;uncl];	% unit normals
rc=[r1;r2;rl];		% position vectors
Nc=length(DSc);		% number of samples

%