function Ef=propff01(rs,Ms,th,ph,k0)
%	Radiative Far-Field Propagator
%
%	rs	Ns by 3 array, source position vectors
%	Ms	Ns by 3 array, source currents
% 	th	Nf by 1 array, theta angles, radians
%	ph	Nf by 1 array, phi angles, radians 
%	k0	wavenumber, radians/inch
%
%	Ns	number of source points
%	Nf	number of field poins
%

Ns=length(rs(:,1));	% number of source points
Nf=length(th);		% number of field points

INs=ones(Ns,1);		% Ns by 1 array of ones
INf=ones(Nf,1);		% Nf by 1 array of ones	

urf=[cos(ph).*sin(th) sin(ph).*sin(th) cos(th)];
		% Nf by 1 array, far field unit vectors
uth=[cos(ph).*cos(th) sin(ph).*cos(th) -sin(th)];
		% Nf by 1 array, theta unit vectors
uph=[-sin(ph) cos(ph) zeros(Nf,1)];
		% Nf by 1 array, phi unit vectors

g0=1/4/pi*exp(-i*k0*urf*rs');
		% Nf by Ns array, scalar Green's functions

Gth=i*k0*g0.*(uph*Ms.');  
		% Nf by Ns array, theta Green's function
Gph=-i*k0*g0.*(uth*Ms.'); 
		% Nf by Ns array, phi Green's function

Eth=Gth*INs;	% Nf by 1 array, theta field density
Eph=Gph*INs;	% Nf by i array, phi field density

Ef=[Eth Eph];

%