      FUNCTION ALINP(X,XA,YA,NP,NI)
C 
C  INTERPOLATION ON TABLE 
C 
C  XA,YA  ARRAYS WITH NP POINTS, MONOTONIC X
C  NI  NUMBER OF POINTS IN INTERPOLATION (LAGRANGE) 
C 
      DIMENSION XA(1),YA(1),XI(5),YI(5) 
      NO=NI 
      IF(NO.GT.5)NO=5 
      NH=NO/2 
      OF=1. 
      IF(XA(NP).LT.XA(1))OF=-1. 
      NS=0
      IF((X-XA(NH))*OF.LT.0.)GOTO2
      NS=NP-NI
      NE=NP-NH
      IF((X-XA(NE))*OF.GT.0.)GOTO2
      NM=NH+1 
      DO1I=NM,NE
      NS=I-NM 
      IF((X-XA(I))*OF.LT.0.)GOTO2 
    1 CONTINUE
    2 DO3I=1,NI 
      J=NS+I
      XI(I)=XA(J) 
    3 YI(I)=YA(J) 
C 
C  INTERPOLATION
C 
      ALINP=0.
      DO4I=1,NI 
      YL=1. 
      DO5J=1,NI 
      IF(I.EQ.J)GOTO5 
      YL=YL*(X-XI(J))/(XI(I)-XI(J)) 
    5 CONTINUE
    4 ALINP=ALINP+YL*YI(I)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE APHI(S,AP)
C 
C  Unit Vector in Phi Direction (Rectangular Coordinates) 
C 
C  S - Spherical Coordinates to location
C  AP - Unit Vector 
C 
      DIMENSION S(1),AP(1)
      AP(1)=-SIN(S(3))
      AP(2)=COS(S(3)) 
      AP(3)=0.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE ARADS(S,AR)
C 
C  Unit Vector in Radius Direction (Rectangular Coordinates)
C 
C  S - Spherical Coordinates
C  AR - Unit Vector 
C 
      DIMENSION S(1),AR(1)
      AR(1)=SIN(S(2))*COS(S(3)) 
      AR(2)=SIN(S(2))*SIN(S(3)) 
      AR(3)=COS(S(2)) 
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE ATHET(S,AT)
C 
C  Unit Vector in Theta Direction (Rectangular Coordinates) 
C 
C  S - Spherical Coordinates of location
C  AT - Unit Vector 
C 
      DIMENSION S(3),AT(3)
      AT(1)=COS(S(2))*COS(S(3)) 
      AT(2)=COS(S(2))*SIN(S(3)) 
      AT(3)=-SIN(S(2))
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE AXRTA(EA,IA,AS)
C
C  Rotation Matrix for Rectangular Coordinates
C
C  EA  Rotation Angle (radians)
C  IA  Axis of rotation: 1 X-axis, 2 Y-axis, 3 Z-axis
C  AS(3,3)  Rotation Matrix
C
      DIMENSION AS(3,3)
      CA=COS(EA)
      SA=SIN(EA)
      IF(IA.EQ.2)SA=-SA
      DO1I=1,3
      DO2J=I,3
      AS(J,I)=-SA
    2 AS(I,J)=SA
    1 AS(I,I)=CA
      DO3I=1,3
      AS(I,IA)=0.
    3 AS(IA,I)=0.
      AS(IA,IA)=1.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION BESJPR(N,X)
C 
C  DERIVATIVE OF BESSEL FUNCTION ORDER N, ARG X 
C
      BESJPR=0.
      IF(ABS(X).EQ.0.)RETURN
      BPO=BESSJN(N+1,X) 
      BESJPR=-BPO+N/X*BESSJN(N,X) 
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      FUNCTION BESSJN(N,X)
C 
C  Bessel Function of Order N and argument X
C 
      IF(N.EQ.0)THEN
      BESSJN=BESSJ0(X)
      ELSE IF(N.EQ.1)THEN 
      BESSJN=BESSJ1(X)
      ELSE
      BESSJN=BESSJ(N,X) 
      ENDIF 
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE BLOCCU(XFD,PKC,ROT,NAP,BNE,BNH,POL,BLOCK,XB,LUNIT)
C
C  Blockage surface currents added to Geometry File
C  for cosine pattern approximation
C
C  XFD(3)   Location of feed
C  PKC      Propagation constant
C
C  Rotated
C  Pattern approximation  I: E = cos(Theta/2)**N
C                        II: E = cos(Theta)**N
C
C  ROT(3,3) Rotation matrix
C  NAP      Pattern approximation number
C  BNE      Exponent in E plane
C  BNH      Exponent in H plane
C  POL      Polarization: 0 Linear, -1 RHC, +1 LHC
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C
      DIMENSION XFD(3),ROT(3,3),FREC(19),XB(1),XFR(3),SP(3),
     1 VR(3),VT(3),VP(3)
      COMPLEX CURJ(3),ETHETA,EPHI,PHA,HFIELD(3),UNIT(3),EFIELD(3),
     1 CURM(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 4 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for feed blockage
      IF(BLOCK(XB,XFD,FREC).NE.1)THEN
C  ------------- Find vector from feed to reflector point
      CALL VLINC(-1.,XFD,1.,FREC,XFR)
      CALL RETSP(XFR,SP)
      CALL FFDIRC(SP(2),SP(3),VR,VT,VP)
C  ------------- Find field
      CALL RCSPAT(ROT,NAP,SP(2),SP(3),BNE,BNH,POL,ETHETA,EPHI)
      PHASE=-SP(1)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))/SP(1)
      DO 1 L=1,3
      UNIT(L)=VR(L)/ZZ
    1 EFIELD(L)=(ETHETA*VT(L)+EPHI*VP(L))*PHA
      CALL CCROSS(UNIT,EFIELD,HFIELD)
      DO 2 J=1,3
    2 UNIT(J)=FREC(J+4)*FREC(4)
      CALL CCROSS(UNIT,HFIELD,CURJ)
      CALL CCROSS(EFIELD,UNIT,CURM)
      ELSE
C  ------------- Blocked
      DO 3 J=1,3
      CURM(J)=0.
    3 CURJ(J)=0.
      ENDIF
    4 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE BLOCIU(XFD,PKC,ROT,BLOCK,XB,LUNIT)
C
C  Blockage surface currents added to Geometry File
C  for interpolated source
C
C  XFD(3)   Location of feed
C  PKC      Propagation constant
C
C  ROT(3,3) Rotation matrix
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C
      DIMENSION XFD(3),ROT(3,3),FREC(19),XB(1),XFR(3),SP(3),
     1 VR(3),VT(3),VP(3)
      COMPLEX CURJ(3),ETHETA,EPHI,PHA,HFIELD(3),UNIT(3),EFIELD(3),
     1 CURM(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 4 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for feed blockage
      IF(BLOCK(XB,XFD,FREC).NE.1)THEN
C  ------------- Find vector from feed to reflector point
      CALL VLINC(-1.,XFD,1.,FREC,XFR)
      CALL RETSP(XFR,SP)
      CALL FFDIRC(SP(2),SP(3),VR,VT,VP)
C  ------------- Find field
      CALL RINPAT(ROT,2,SP(2),SP(3),ETHETA,EPHI)
      PHASE=-SP(1)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))/SP(1)
      DO 1 L=1,3
      UNIT(L)=VR(L)
    1 EFIELD(L)=(ETHETA*VT(L)+EPHI*VP(L))*PHA
      CALL CCROSS(UNIT,EFIELD,HFIELD)
      DO 2 J=1,3
      HFIELD(J)=HFIELD(J)/ZZ
    2 UNIT(J)=FREC(J+4)*FREC(4)
      CALL CCROSS(UNIT,HFIELD,CURJ)
      CALL CCROSS(EFIELD,UNIT,CURM)
      ELSE
C  ------------- Blocked
      DO 3 J=1,3
      CURM(J)=0.
    3 CURJ(J)=0.
      ENDIF
    4 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION BLOCKN(XB,XS,XF)
C
C  Null blockage function
C
      DIMENSION XB(1),XS(1),XF(1)
      BLOCKN=0.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      COMPLEX FUNCTION CCDOT(X,Y)
C
C  Dot Product between two Complex Vectors: X and Y
C
      COMPLEX X(1),Y(1)
      CCDOT=X(1)*Y(1)+X(2)*Y(2)+X(3)*Y(3)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CCROSS(A,B,C)
C 
C  Complex Vector Cross Product A X B = C
C 
C  Vectors are Expressed in Rectangular Coordinates 
C 
      COMPLEX A(1),B(1),C(1)
      C(1)=A(2)*B(3)-A(3)*B(2)
      C(2)=A(3)*B(1)-A(1)*B(3)
      C(3)=A(1)*B(2)-A(2)*B(1)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      COMPLEX FUNCTION CCUTAL(R1,R2,F,X,Y,NINT,POL)
C
C  Mutual admittance between two circular patch antennas
C  using currents in common for first patch
C
C  R1      Radius of 1st patch (cm)
C  R2      Radius of 2nd patch (cm)
C  F       Frequency (GHz)
C  X,Y	   Position of 2nd patch (cm)
C  NINT    Number of points in integrals
C  POL	   Polarization: 0 Linear, -1 RHC, +1 LHC
C
C  Note:   Feeds located on X axis
C
      COMPLEX CCDOT,EFIELD(3),HFIELD(3),AM(3),SS
      DIMENSION XF(3),XC(3),XB(1)
      EXTERNAL BLOCKN
      DATA CC/.2997925/,PI/3.14159265/,XC/0.,0.,0./
      RAD1=R1*.01
      RAD2=R2*.01
      WAVEL=CC/F
      HP=2.*PI*RAD2/(NINT-1)
      V1=SQRT(1./CRADCN(RAD1/WAVEL))
      SS=0.
C ------------------- Find reaction along edge
      DO 1 I=1,NINT
      POS=HP*(I-1)
      CALL CPPERM(POS,RAD2,XF,AM,POL)
      XF(1)=XF(1)+X*.01
      XF(2)=XF(2)+Y*.01
C ------------------- Find fields at point due to 1st patch
      CALL NFPATR(XC,BLOCKN,XB,XF,EFIELD,HFIELD)
C ------------------- Find reaction at point
    1 SS=CCDOT(HFIELD,AM)*HP+SS
C ------------------- Half space radiation, reduce by 1/2
      CCUTAL=-SS/V1/2.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CHRCUR(VE,VM,AP,BP,N,RADB,SLANT,AKP,AKF,ALINC,LUNIT)
C
C  Currents File of Circular Corrugated Waveguide Horn
C
C  VE      Voltage magnitude of TE component
C  VM      Voltage magnitude of TM component
C          VM/VE = Hybrid mode ratio
C          If VM = 0, TE mode horn
C          If VE = 0, TM mode horn
C  AP      Amplitude of cosinusoidal circumferentially-varying field
C  BP      Amplitude of sinusoidal circumferentially-varying field
C  N       Order of circumferentially-varying field
C  RADB    Outer radius (m)
C  SLANT   Slant radius of horn
C  AKP     Radial component propagation constant
C  AKF     Propagation constant in free space
C  ALINC   Length increment for current patches
C  NR      Number of points in radial integrals
C  NP      Number of points in Phi integrals
C  LUNIT   Logical unit of random access file for currents
C
      COMPLEX CURJ(3),CURM(3),QUAD,VE,VM,AP,BP,ER,EP,HR,HP,CJ,
     1 PSI,PHI
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      DATA PI/3.141592654/,CJ/(0.,1.)/,ZZ/376.73/
      AKZ=AKF**2-AKP**2
C ------------- Check for cutoff
      IF(AKZ.LE.0.)RETURN
      AKZ=SQRT(AKZ)
      CURJ(3)=0.
      CURM(3)=0.
      POWER=0.
      NR=RADB/ALINC+.5
      DR=RADB/NR
      FREC(3)=0.
      PK=AKF
      KREC=1
C ------------- Loop over radius
      DO 2 J=1,NR
      RAD=(FLOAT(J-1)+.5)*DR
      BJ=BESSJN(N,RAD*AKP)
      BJP=BESJPR(N,RAD*AKP)
C ------------- Find differential area
      R1=RAD-DR/2.
      R2=RAD+DR/2.
C ------------- Quadratic phase factor
      S=AKF*RAD**2/SLANT/2.
      QUAD=CMPLX(COS(S),-SIN(S))
C ------------- Loop over Phi
      NP=2.*PI*RAD/ALINC+.5
      DP=2.*PI/NP
      DO 1 I=1,NP
      PH=FLOAT(I-1)*DP
C ------------- Circumferential variation
      PSI=AP*COS(N*PH)+BP*SIN(N*PH)
      PHI=BP*COS(N*PH)-AP*SIN(N*PH)
C ------------- Rho and Phi components
      ER=-CJ*ZZ*PSI*(AKZ*BJP*VM+AKF*N*BJ*VE/RAD/AKP)/AKP*QUAD
      EP=-CJ*ZZ*PHI*(AKZ*N*VM*BJ/RAD/AKP+VE*AKF*BJP)/AKP*QUAD
      HR=CJ*PHI*(AKF*N*VM*BJ/RAD/AKP+AKZ*VE*BJP)/AKP*QUAD
      HP=-CJ*PSI*(AKF*BJP*VM+AKZ*N*BJ*VE/RAD/AKP)/AKP*QUAD
C ------------- Differential area and position
      FREC(4)=DP*(R2**2-R1**2)/2.
      FREC(1)=RAD*COS(PH)
      FREC(2)=RAD*SIN(PH)
C ------------- Normalized magnetic and electric currents * Area
      CURJ(1)=-(HR*SIN(PH)+HP*COS(PH))*FREC(4)
      CURJ(2)=(HR*COS(PH)-HP*SIN(PH))*FREC(4)
      CURM(1)=(ER*SIN(PH)+EP*COS(PH))*FREC(4)
      CURM(2)=-(ER*COS(PH)-EP*SIN(PH))*FREC(4)
C ------------- Normalized aperture power * Area
      POWER=POWER+(CABS(CURM(2)*CURJ(1))
     1 +CABS(CURM(1)*CURJ(2)))/FREC(4)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      CURN=SQRT(POWER)
C ------------- Normalize aperture power to 1 watt
      DO 3 I=2,KREC
      READ(LUNIT,REC=I)(FREC(NN),NN=1,19)
      CURM(1)=CURM(1)/CURN
      CURM(2)=CURM(2)/CURN
      CURJ(1)=CURJ(1)/CURN
      CURJ(2)=CURJ(2)/CURN
    3 WRITE(LUNIT,REC=I)(FREC(NN),NN=1,19)
      IBUF(1)=KREC-1
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CMTMUL(AM,X,Y)
C
C  Matrix multiplication between Complex Matrix and Complex Vector
C
C  AM(3,3)   Complex matrix
C  X(3)      Complex vector
C  Y(3)      Resulting vector
C
      COMPLEX AM(3,3),X(3),Y(3)
      DO2I=1,3
      Y(I)=0.
      DO1J=1,3
    1 Y(I)=Y(I)+AM(I,J)*X(J)
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CONEGEO(P1,P2,RAD1,RAD2,ALINC,LUNIT,ICAT)
C
C  Geometry file of Truncated Cone
C
C  P1(3)      Starting point of cone (m)
C  P2(3)      End point of axis  (m)
C  RAD1       Radius of cone at point P1
C  RAD2       Radius of cone at point P2
C  ALINC      Current patch increment (m)
C  LUNIT      Logical unit of disk file
C  ICAT       If 1, concatenate
C
      DIMENSION P1(3),P2(3),AXIS(3),SP(3),FREC(19),ROT(3,3),EU(3),
     1 IA(3),POS(3),VEC(3)
      INTEGER*4 IBUF(19)
      DATA PI/3.141592654/,IA/3,2,3/
      CALL VLINC(1.,P2,-1.,P1,AXIS)
      CALL RETSP(AXIS,SP)
      ANGLE=ATAN((RAD2-RAD1)/SP(1))
C  ------------ Find axis increment: ALEN
      NL=SP(1)/ALINC/COS(ANGLE)+.5
      ALEN=SP(1)/NL
C  ------------ Find rotation matrix
      EU(1)=SP(3)
      EU(2)=SP(2)
      EU(3)=0.
      CALL EULER(EU,IA,ROT)
C  ------------ Layout cone along Z-axis
      IF(ICAT.EQ.1)THEN
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=IBUF(1)+1
      ELSE
      KREC=1
      ENDIF
      DO 2 I=1,NL
      POS(3)=(I-.5)*ALEN
      Z2=I*ALEN
      Z1=(I-1)*ALEN
      RADIUS=RAD1+POS(3)*(RAD2-RAD1)/SP(1)
      NP=2.*PI*RADIUS/ALINC+.5
      NP=NP/4
      NP=(NP+1)*4
      AINC=2.*PI/NP
C  ------------ Find patch area
      FREC(4)=AINC*(RAD1*ALEN+(Z2**2-Z1**2)*0.5*TAN(ANGLE))/
     1 COS(ANGLE)
      DO 1 J=1,NP
      ANG=(J-1)*AINC
C  ------------ Find position
      POS(1)=RADIUS*COS(ANG)
      POS(2)=RADIUS*SIN(ANG)
      CALL MTMULT(POS,ROT,VEC,1,3,3)
      CALL VLINC(1.,VEC,1.,P1,FREC)
C  ------------ Find normal vector
      VEC(1)=COS(ANG)*COS(ANGLE)
      VEC(2)=SIN(ANG)*COS(ANGLE)
      VEC(3)=-SIN(ANGLE)
      CALL MTMULT(VEC,ROT,FREC(5),1,3,3)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      IBUF(1)=KREC-1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE COSPAT(NAP,THETA,PHI,BNE,BNH,POL,ETHETA,EPHI)
C
C  Pattern approximation  I: E = cos(Theta/2)**N
C                        II: E = cos(Theta)**N
C
C  NAP      Pattern approximation number
C  THETA    Pattern angle (radians)
C  PHI      Pattern angle (radians)
C  BNE      Exponent in E plane
C  BNH      Exponent in H plane
C  POL      Polarization: 0 Linear, -1 RHC, +1 LHC
C  ETHETA   Theta component  V/m for 1 watt radiated power at 1 m.
C  EPHI     Phi component    V/m for 1 watt radiated power at 1 m.
C
      COMPLEX ETHETA,EPHI
      DATA GCONS/.1826374/,SQ2/1.4142135/
C ------------------- GCONS = SQRT(4*PI/376.73)
      DE=NAP*(NAP*BNE+1.)
      DH=NAP*(NAP*BNH+1.)
      DIRECT=2.*DE*DH/(DE+DH)
      CT=COS(THETA*NAP/2.)
      IF(CT.LE.0.)THEN
      EE=0.
      ELSE
C ------------------- Elliptical beam approximation
      EE=SQRT(CT**(2.*BNE)*COS(PHI)**2+CT**(2.*BNH)*SIN(PHI)**2)
      ENDIF
C ------------------- Adjust to V/m for 1 w. Input at radius = 1 m.
      EE=EE*SQRT(DIRECT)/GCONS
      IF(POL.EQ.0.)THEN
C ------------------- Linear polarization, X-axis directed
      ETHETA=EE*COS(PHI)
      EPHI=-EE*SIN(PHI)
      ELSE
C ------------------- Circular polarization, Phase = 0 at Phi = 0
      ETHETA=EE*CMPLX(COS(PHI),POL*SIN(PHI))/SQ2
      EPHI=CMPLX(0.,POL)*ETHETA
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CPACUR(RADIUS,FREQ,POL,NPTS,LUNIT)
C
C  Currents file of circular microstrip patch
C
C  RADIUS    Effective radius of patch (m)
C  FREQ      Frequency (GHz)
C  POL	     Polarization: 0 linear, -1 RHC, +1 LHC
C  NPTS      Number of points in integrals
C
C  LUNIT     Logical unit of random access file with currents
C
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      COMPLEX CURM(3),AM(3)
      EQUIVALENCE (IBUF(3),PK),(FREC(14),CURM(1))
      DATA CC/.2997925/,PI/3.141592654/
      WAVEL=CC/FREQ
      PK=2.*PI/WAVEL
      RAD=RADIUS/WAVEL
C --------------- Find maximum magnetic current for 1 w. input
      AMM=2.*SQRT(1./CRADCN(RAD))
      IBUF(1)=NPTS
      IBUF(2)=2
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=1
      PER=2.*PI*RADIUS
      HP=PER/NPTS
      DO 2 I=1,NPTS
      POS=HP*(I-1)
      CALL CPPERM(POS,RADIUS,FREC,AM,POL)
      KREC=KREC+1
      DO 1 K=1,3
    1 CURM(K)=AM(K)*AMM*HP
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION CPGAIN(RAD)
C
C  Circular Patch Gain dB: RAD Radius in wavelengths
C
      DIMENSION RRD(25),ZR(25)
      DATA RRD/.06,.07,.08,.09,.1,.11,.12,.13,.14,.15,.16,.17,.18,.19,
     1 .2,.21,.22,.23,.24,.25,.26,.27,.28,.29,.3/
      DATA ZR/103.56,89.684,79.408,71.539,65.358,60.408,56.386,53.081,
     1 50.343,48.061,46.154,44.557,43.22,42.103,41.173,40.401,39.762,
     2 39.234,38.794,38.421,38.093,37.789,37.487,37.163,36.796/
      DATA PI/3.14159265/,ZZO/376.73/
      ZZ=ALINP(RAD,RRD,ZR,25,3)
      GAIN=PI/ZZO*(PI*RAD*ZZ)**2
      CPGAIN=10.*ALOG10(GAIN)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CPPERM(P,RAD,POS,AM,POL)
C
C  Perimeter function of circular patch
C
C  P   Perimeter value (0 starts on X axis)
C  RAD Radius
C  POS    Position on patch centered on origin
C  AM(3)  Normalized magnetic current direction
C  POL	  Polarization: 0 Linear, -1 RHC, +1 LHC
C
      DIMENSION POS(3)
      COMPLEX AM(3)
      DATA S2/1.1421356/
      PH=P/RAD
      POS(3)=0.
      AM(3)=0.
      AM(1)=-SIN(PH)*COS(PH)
      AM(2)=COS(PH)*COS(PH)
      IF(POL.NE.0.)THEN
      AM(1)=(AM(1)-CMPLX(0.,POL)*SIN(PH)*SIN(PH))/S2
      AM(2)=(AM(2)+CMPLX(0.,POL)*COS(PH)*SIN(PH))/S2
      ENDIF
      POS(1)=COS(PH)*RAD
      POS(2)=SIN(PH)*RAD
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION CRADCN(RAD)
C
C  Radiation conductance for circular patch: RAD Radius in wavelengths
C
      DIMENSION RRD(25),ZR(25)
      DATA RRD/.06,.07,.08,.09,.1,.11,.12,.13,.14,.15,.16,.17,.18,.19,
     1 .2,.21,.22,.23,.24,.25,.26,.27,.28,.29,.3/
      DATA ZR/103.56,89.684,79.408,71.539,65.358,60.408,56.386,53.081,
     1 50.343,48.061,46.154,44.557,43.22,42.103,41.173,40.401,39.762,
     2 39.234,38.794,38.421,38.093,37.789,37.487,37.163,36.796/
      ZZ=ALINP(RAD,RRD,ZR,25,3)
      CRADCN=1./(ZZ/2.)**2
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CROSS(A,B,C)
C 
C  Vector Cross Product A X B = C 
C 
C  Vectors are Expressed in Rectangular Coordinates 
C 
      DIMENSION A(1),B(1),C(1)
      C(1)=A(2)*B(3)-A(3)*B(2)
      C(2)=A(3)*B(1)-A(1)*B(3)
      C(3)=A(1)*B(2)-A(2)*B(1)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE CURADD(LUNIT,LADD)
C
C  Add currents in file LADD to currents in LUNIT
C
      DIMENSION FREC(19),FRECC(19)
      COMPLEX CURJ(3),CURJJ(3),CURM(3),CURMM(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (FREC(8),CURJ(1)),(FRECC(8),CURJJ(1)),
     1 (FREC(14),CURM(1)),(FRECC(14),CURMM(1))
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 2 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      READ(LADD,REC=I+1)(FRECC(NN),NN=1,19)
      DO 1 J=1,3
      CURJ(J)=CURJ(J)+CURJJ(J)
    1 CURM(J)=CURM(J)+CURMM(J)
    2 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CURCAT(LUNIT)
C
C  Read currents from file and concatenates into CURRENT common
C
C  LUNIT    Logical unit of random access file (open file)
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3)
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 2 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      K=NCUR+I
      DO 1 J=1,3
      POSC(J,K)=FREC(J)
      CURJA(J,K)=CURJ(J)
    1 CURMA(J,K)=CURM(J)
    2 CONTINUE
      NCUR=NCUR+IBUF(1)
      IF(NCTYP.EQ.0.OR.IBUF(2).EQ.0)NCTYP=0
      IF(NCTYP.NE.IBUF(2))NCTYP=0
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CURCOM(LUNIT)
C
C  Read currents from file into CURRENT common
C
C  LUNIT    Logical unit of random access file (open file)
C
C  File:  76 Bytes record
C
C  Record 1
C
C  Number of records
C  Types of currents available: 0 both, 1 electric only, 2 magnetic only
C  Propagation constant (1./meters)
C
C  Record 2 - NCUR+1
C
C  Position(3)   meters
C  Area          meters**2
C  Normal(3)     Unit normal to patch
C  J(3)          Electric current * area
C  M(3)          Magnetic current * area
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3)
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      NCUR=IBUF(1)
      NCTYP=IBUF(2)
      PKC=PK
      DO 2 I=1,NCUR
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      DO 1 J=1,3
      POSC(J,I)=FREC(J)
      CURJA(J,I)=CURJ(J)
    1 CURMA(J,I)=CURM(J)
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CURCON(PKC,VR,HFIELD,NPLTS,LUNIT,ITER)
C
C  Currents convergence for Incident plane wave
C
C  PKC    Propagation constant
C  VR(3)  Incident wave direction
C  HFIELD Incident wave magnetic field
C  NPLTS  Number of plates
C  LUNIT  Array of logical units
C
      DIMENSION VR(3),LUNIT(1),XBB(1),XC(3)
      COMPLEX HFIELD(3)
      EXTERNAL BLOCKN
      DATA XC/0.,0.,0./
C  -----------  Find initial currents into first files
      DO 2 IP=1,NPLTS
      CALL REFPCU(PKC,VR,HFIELD,BLOCKN,XBB,LUNIT(IP),1)
C  ----------- Move geometry into third files
      IPP=IP+2*NPLTS
      CALL CUREQU(LUNIT(IP),LUNIT(IPP))
      IPP=IP+NPLTS
C  -----------  Move initial currents into second files
    2 CALL CUREQU(LUNIT(IP),LUNIT(IPP))
C  -----------  Loop for convergence
      DO 6 INR=1,ITER
C  ----------- Move all currents into common except plate
      DO 4 IP=1,NPLTS
      K=1
      DO 3 IL=1,NPLTS
      IF(IP.EQ.IL)GOTO3
      IPP=IL+NPLTS
      IF(K.EQ.1)THEN
      CALL CURCOM(LUNIT(IPP))
      K=2
      ELSE
      CALL CURCAT(LUNIT(IPP))
      ENDIF
    3 CONTINUE
C  ----------- Find third file currents due to currents in common
      IPP=IP+2*NPLTS
      CALL REFCUR(XC,PKC,BLOCKN,XBB,LUNIT(IPP),0)
    4 CONTINUE
C  ----------- Sum currents into 1st file
      DO 5 IP=1,NPLTS
      IPP=IP+2*NPLTS
      CALL CURADD(LUNIT(IP),LUNIT(IPP))
C  ----------- Move third file currents into second files
      IQQ=IP+NPLTS
    5 CALL CUREQU(LUNIT(IPP),LUNIT(IQQ))
    6 CONTINUE
C  ----------- Concatenate currents into common
      CALL CURCOM(LUNIT(1))
      DO 7 I=2,NPLTS
    7 CALL CURCAT(LUNIT(I))
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CUREQU(IIN,IOUT)
C
C  Equate geometry and currents files
C
C  IIN  - Input LU,  IOUT - Output LU
C
      INTEGER*4 IBUF(19)
      READ(IIN,REC=1)(IBUF(NN),NN=1,19)
      NC=IBUF(1)+1
      DO 1 I=1,NC
      READ(IIN,REC=I)(IBUF(NN),NN=1,19)
    1 WRITE(IOUT,REC=I)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CURROT(ROT,CENT)
C
C  Rotation of Currents in Common about point in space
C
C  ROT(3,3)   Rotation matrix
C  CENT(3)    Center of rotation
C
      DIMENSION ROT(3,3),CENT(3),XC(3),XA(3)
      COMPLEX CURJA,CURMA,CURJI(3),CURJO(3),CURMI(3),CURMO(3)
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      DO 3 K=1,NCUR
      DO 1 J=1,3
      XC(J)=POSC(J,K)-CENT(J)
      CURJI(J)=CURJA(J,K)
    1 CURMI(J)=CURMA(J,K)
      CALL MTMULT(XC,ROT,XA,1,3,3)
      CALL CVTROT(CURJI,ROT,CURJO)
      CALL CVTROT(CURMI,ROT,CURMO)
      DO 2 J=1,3
      POSC(J,K)=XA(J)+CENT(J)
      CURJA(J,K)=CURJO(J)
    2 CURMA(J,K)=CURMO(J)
    3 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CURSUM(POWER,PHASE,LUNIT)
C
C  Sums currents from file into CURRENT common
C
C  POWER    Power in mode (watts) - Power in all modes should sum to 1
C  PHASE    Phase of mode (degrees)
C  LUNIT    Logical unit of random access file (open file)
C
C  File:  76 Bytes record
C
C  Record 1
C
C  Number of records
C  Types of currents available: 0 both, 1 electric only, 2 magnetic only
C  Propagation constant (1./meters)
C
C  Record 2 - NCUR+1
C
C  Position(3)   meters
C  Area          meters**2
C  Normal(3)     Unit normal to patch
C  J(3)          Electric current * area
C  M(3)          Magnetic current * area
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3),CV
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      DATA TR/.01745329/
      CV=SQRT(POWER)*CMPLX(COS(PHASE*TR),SIN(PHASE*TR))
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      NCUR=IBUF(1)
      IF(IBUF(2).EQ.0.OR.NCTYP.EQ.0)THEN
      NCTYP=0.
      ELSE
      IF(IBUF(2).EQ.1.AND.NCTYP.EQ.2)NCTYP=0
      IF(IBUF(2).EQ.2.AND.NCTYP.EQ.1)NCTYP=0
      ENDIF
      PKC=PK
      DO 2 I=1,NCUR
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      DO 1 J=1,3
      CURJA(J,I)=CURJ(J)*CV+CURJA(J,I)
    1 CURMA(J,I)=CURM(J)*CV+CURMA(J,I)
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE CVTROT(CURI,ROT,CURO)
C
C  Rotation of Complex Vector by rotation matrix
C
C  CURI(3)    Input vector
C  ROT(3,3)   Rotation matrix
C  CURO(3)    Output vector
C
      DIMENSION ROT(3,3)
      COMPLEX CURI(3),CURO(3)
      DO 2 I=1,3
      CURO(I)=0.
      DO 1 J=1,3
    1 CURO(I)=CURO(I)+CURI(J)*ROT(J,I)
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION DOT(A,B)
C 
C  Determines Scalar Product of 2 Vectors A & B 
C 
      DIMENSION A(1),B(1) 
      DOT=0.  
      DO10I=1,3 
   10 DOT=A(I)*B(I)+DOT 
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      FUNCTION DSKBLF(XB,XS,VR)
C
C  Disk blockage function for far field
C
C  XB(1)  X position of disk center
C     2   Y position of disk center
C     3   Z position of disk center
C     4   Radius of disk
C     5   Unit normal to disk (X component)
C     6   Unit normal to disk (Y component)
C     7   Unit normal to disk (Z component)
C  XS     Source point
C  VR     Radial unit vector
C
      DIMENSION XB(1),XS(1),VR(1),P(3)
      DSKBLF=0.
      CALL PINTS(XS,VR,XB(1),XB(5),T,P,NIS)
      IF(NIS.EQ.-1)RETURN
      DIST=SQRT((P(1)-XB(1))**2+(P(2)-XB(2))**2+(P(3)-XB(3))**2)
      IF(DIST.GT.XB(4).OR.T.LT.0)RETURN
      DSKBLF=1
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION DSKBLN(XB,XS,XF)
C
C  Disk blockage function for near field
C
C  XB(1)  X position of disk center
C     2   Y position of disk center
C     3   Z position of disk center
C     4   Radius of disk
C     5   Unit normal to disk (X component)
C     6   Unit normal to disk (Y component)
C     7   Unit normal to disk (Z component)
C  XS     Source point
C  XF     Field point
C
      DIMENSION XB(1),XS(1),XF(1),P(3),FS(3)
      CALL VLINC(-1.,XS,1.,XF,FS)
      FSL=SQRT(DOT(FS,FS))
      DO 1 I=1,3
    1 FS(I)=FS(I)/FSL
      DSKBLN=0.
      CALL PINTS(XS,FS,XB(1),XB(5),T,P,NIS)
      IF(NIS.EQ.-1)RETURN
      DIST=SQRT((P(1)-XB(1))**2+(P(2)-XB(2))**2+(P(3)-XB(3))**2)
      IF(DIST.GT.XB(4).OR.T.LT.0.)RETURN
      IF(DIST.LE.XB(4).AND.T.GT.FSL)RETURN
      DSKBLN=1
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE DURGEO(DMAIN,DSUB,FOD,FED,TYPE,A,B,CENT,FEED)
C
C  Dual Reflector Geometry
C
C  DMAIN    Diameter of main reflector
C  DSUB     Diameter of subreflector
C  FOD      Main reflector f/D
C  FED      Effective f/D of dual reflector system
C  TYPE     1) Hyperboloid (Cassegrain), 2) Ellipsoid (Gregorian)
C
C  A	    Z-axis factor of subreflector curve
C  B	    Radial factor of subreflector curve
C  CENT(3)  Location of center of subreflector geometry
C  FFED(3)  Location of feed
C
      DIMENSION CENT(3),FEED(3)
      AMAG=FED/FOD
      E=(AMAG+1.)/(AMAG-1.)
      IF(TYPE.EQ.2)E=1./E
C -------- Half subtended of main and subreflector at focus & feed
      PHIO=2.*ATAN(1./(4.*FOD))
      THO=2.*ATAN(1./(4.*FED))
      IF(TYPE.EQ.1)THEN
      PZ=2.*E*E/(E*E-1.)
      P=DSUB*(E*COS(THO)-1.)/(2.*E*SIN(THO))
      ELSE IF(TYPE.EQ.2)THEN
      PZ=2.*E*E/(1.-E*E)
      P=-DSUB*(E*COS(THO)-1.)/(2.*E*SIN(THO))
      ENDIF
C -------- Subreflector parameters 2*C, A, and B
      TC=PZ*P
      A=TC/2./E
      B=SQRT(ABS((TC/2.)**2-A**2))
      FOCUS=FOD*DMAIN
      FEED(1)=0.
      FEED(2)=0.
      FEED(3)=FOCUS-TC
      CENT(1)=0.
      CENT(2)=0.
      CENT(3)=FOCUS-TC/2.
      RETURN
      END



      FUNCTION ELLBLF(XB,XS,VR)
C
C  Elliptical Disk Blockage function for far field
C
C  XB(1)   X position of disk center
C    (2)   Y position of disk center
C    (3)   Z position of disk center
C    (4)   Major Axis Radius
C    (5)   Minor Axis Radius
C    (6)   Unit normal to disk (X component)
C    (7)   Unit normal to disk (Y component)
C    (8)   Unit normal to disk (Z component)
C    (9)   Unit vector from center along major axis (X component)
C    (10)  Unit vector from center along major axis (Y component)
C    (11)  Unit vector from center along major axis (Z component)
C  XS      Source point
C  VR      Radial unit vector
C
      DIMENSION XB(1),XS(1),VR(1),P(3),Y(3),RV(3)
      ELLBLF=0.
      CALL PINTS(XS,VR,XB(1),XB(7),T,P,NIS)
      IF(NIS.EQ.-1)RETURN
      CALL CROSS(XB(6),XB(9),Y)
      CALL VLINC(1.,P,-1.,XB,RV)
      V=(DOT(RV,XB(9))/XB(4))**2+(DOT(RV,Y)/XB(5))**2-1.
      IF(V.LE.0.)ELLBLF=1.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION ELLBLN(XB,XS,XF)
C
C  Elliptical Disk Blockage function for near field
C
C  XB(1)   X position of disk center
C    (2)   Y position of disk center
C    (3)   Z position of disk center
C    (4)   Major Axis Radius
C    (5)   Minor Axis Radius
C    (6)   Unit normal to disk (X component)
C    (7)   Unit normal to disk (Y component)
C    (8)   Unit normal to disk (Z component)
C    (9)   Unit vector from center along major axis (X component)
C    (10)  Unit vector from center along major axis (Y component)
C    (11)  Unit vector from center along major axis (Z component)
C  XS      Source point
C  XF      Field point
C
      DIMENSION XB(1),XS(1),XF(1),P(3),Y(3),RV(3),FS(3)
      ELLBLN=0.
      CALL VLINC(-1.,XS,1.,XF,FS)
      FSL=SQRT(DOT(FS,FS))
      DO 1 I=1,3
    1 FS(I)=FS(I)/FSL
      CALL PINTS(XS,FS,XB(1),XB(7),T,P,NIS)
      IF(NIS.EQ.-1)RETURN
      CALL CROSS(XB(6),XB(9),Y)
      CALL VLINC(1.,P,-1.,XB,RV)
      V=(DOT(RV,XB(9))/XB(4))**2+(DOT(RV,Y)/XB(5))**2-1.
      IF(V.LE.0.)ELLBLN=1.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE EULER(EA,IA,AS)
C 
C  Euler Rotation Matrix
C 
C  EA  Array of Euler Angles (radians) Positive gives CCW rotation
C      about axis specified by IA 
C  IA  Array of Axis Designators (1 X-axis, 2 Y-axis, 3 Z-axis) 
C      For example, rotation about Z axis, New Y axis, New Z axis 
C      would require IA to be: 3,2,3
C 
C  AS  (3,3) Matrix of rotation 
C 
      DIMENSION EA(3),IA(3),AS(3,3),AW(3,3),BW(3,3)
      CALL AXRTA(EA(1),IA(1),AS)
      CALL AXRTA(EA(2),IA(2),BW)
      CALL MTMULT(BW,AS,AW,3,3,3) 
      CALL AXRTA(EA(3),IA(3),BW)
      CALL MTMULT(BW,AW,AS,3,3,3) 
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE FFDIRC(THETA,PHI,VR,VT,VP)
C
C  Far Field direction vectors
C
C  THETA, PHI   Pattern angles (radians)
C  VR(3)        Radius unit vector
C  VT(3)        Theta polarization unit vector
C  VP(3)        Phi polarization unit vector
C
      DIMENSION S(3),VR(3),VT(3),VP(3)
      S(1)=1.
      S(2)=THETA
      S(3)=PHI
      CALL ARADS(S,VR)
      CALL ATHET(S,VT)
      CALL APHI(S,VP)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE FFPATF(LUNIT,XC,BLOCK,XB,THETA,PHI,ETHETA,EPHI)
C
C  Far field pattern from currents in file
C
C  LUNIT     Logical unit of open file
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  THETA     Angle from Z axis (boresight) (radians)
C  PHI       Spherical angle from X-axis (radians)
C  ETHETA    Electric field in Theta direction
C  EPHI      Electric field in Phi direction
C
      COMPLEX ETHETA,EPHI,CURJ(3),CURM(3),ETH,EPH,CONJ
      DIMENSION VR(3),VT(3),VP(3),XS(3),XC(3),XB(1),FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------------- -j*2*Pi*Frequency*Mu
      CONJ=CMPLX(0.,-PK*CC*400.*PI)
      NCUR=IBUF(1)
      NCTYP=IBUF(2)
      ETHETA=0.
      EPHI=0.
      DO 2 I=1,NCUR
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      DO 1 J=1,3
    1 XS(J)=FREC(J)+XC(J)
      IF(BLOCK(XB,XS,VR).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJF(VR,VT,VP,XS,PK,CURJ,ETH,EPH)
      ETHETA=ETHETA+ETH*CONJ
      EPHI=EPHI+EPH*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGRHJF(VR,VT,VP,XS,PK,CURM,ETH,EPH)
      ETHETA=ETHETA-ETH
      EPHI=EPHI-EPH
      ENDIF
      ENDIF
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE FFPATI(XC,BLOCK,XB,THETA,PHI,ETHETA,EPHI)
C
C  Far field pattern from currents in common for image in gr.pl.
C  with dielectric slab to top surface at Z = 0
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  THETA     Angle from Z axis (boresight) (radians)
C  PHI       Spherical angle from X-axis (radians)
C  ETHETA    Electric field in Theta direction
C  EPHI      Electric field in Phi direction
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
      COMMON /DIELECT/ERS,THS,URS,ITEM
C
C  Dielectric slab common: /DIELECT/
C  ERS	  Dielectric constant
C	  ER*cmplx(1.,-(loss tangent)) or
C	  cmplx(ER,-(conductivity(S/m))/(2*pi*8.854185e-12*frequency))
C  THS	  Thickness (m)
C  URS	  Relative permeability
C  ITEM   If 1, use TEM approximation
C
      COMPLEX CURJA,CURMA,ETHETA,EPHI,CURJ(3),CURM(3),ETH,EPH,CONJ
     1,ZSTM,ZSTE,GTM,GTE,ERS,PZM,ZMTE,ZMTM
      DIMENSION VR(3),VT(3),VP(3),XS(3),XC(3),XB(1)
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,ZS/376.73/
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
C ------------- -j*2*Pi*Frequency*Mu
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
      ETHETA=0.
      EPHI=0.
      DO 2 I=1,NCUR
      DO 1 J=1,3
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    1 CURM(J)=CURMA(J,I)
      XS(3)=-XS(3)
      IF(BLOCK(XB,XS,VR).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJF(VR,VT,VP,XS,PKC,CURJ,ETH,EPH)
      ETHETA=ETHETA+ETH*CONJ
      EPHI=EPHI+EPH*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGRHJF(VR,VT,VP,XS,PKC,CURM,ETH,EPH)
      ETHETA=ETHETA-ETH
      EPHI=EPHI-EPH
      ENDIF
      ENDIF
    2 CONTINUE
C --------- Incident wave impedances
      ZTM=ZS*VR(3)
      ZTE=ZS/VR(3)
      PZM=PKC*CSQRT((ERS*URS-1.)+VR(3)**2)
      ZMTM=ZS*PZM/PKC/ERS
      ZMTE=ZS*PKC*URS/PZM
      IF(ITEM.EQ.1)THEN
      ZSTM=ZS*CSIN(PKC*THS*CSQRT(ERS))/CCOS(PKC*THS*CSQRT(ERS))*
     1 CMPLX(0.,-1.)/CSQRT(ERS)
      ZSTE=ZSTM
      ELSE IF(ITEM.EQ.-1)THEN
      ZSTM=ZMTM*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ZSTE=ZMTE*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ELSE IF(ITEM.EQ.0)THEN
      ZSTM=ZMTM
      ZSTE=ZMTE
      ENDIF
C --------- Find the reflection coefficients of two polarizations
      GTM=(ZTM-ZSTM)/(ZTM+ZSTM)
      GTE=(ZSTE-ZTE)/(ZSTE+ZTE)
C --------- Reduce reflected fields
      ETHETA=-ETHETA*GTM
      EPHI=EPHI*GTE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE FFPATR(XC,BLOCK,XB,THETA,PHI,ETHETA,EPHI)
C
C  Far field pattern from currents in common
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  THETA     Angle from Z axis (boresight) (radians)
C  PHI       Spherical angle from X-axis (radians)
C  ETHETA    Electric field in Theta direction
C  EPHI      Electric field in Phi direction
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1/meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,ETHETA,EPHI,CURJ(3),CURM(3),ETH,EPH,CONJ
      DIMENSION VR(3),VT(3),VP(3),XS(3),XC(3),XB(1)
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
C ------------- -j*2*Pi*Frequency*Mu
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
      ETHETA=0.
      EPHI=0.
      DO 2 I=1,NCUR
      DO 1 J=1,3
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    1 CURM(J)=CURMA(J,I)
      IF(BLOCK(XB,XS,VR).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJF(VR,VT,VP,XS,PKC,CURJ,ETH,EPH)
      ETHETA=ETHETA+ETH*CONJ
      EPHI=EPHI+EPH*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGRHJF(VR,VT,VP,XS,PKC,CURM,ETH,EPH)
      ETHETA=ETHETA-ETH
      EPHI=EPHI-EPH
      ENDIF
      ENDIF
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE FILROT(LUNIT,ROT,CENT)
C
C  Rotation of Currents in File about point in space
C
C  LUNIT      Logical unit of currents and geometry file
C  ROT(3,3)   Rotation matrix
C  CENT(3)    Center of rotation
C
      DIMENSION ROT(3,3),CENT(3),XC(3),XA(3),FREC(19)
      INTEGER*4 IBUF(19)
      COMPLEX CURJ(3),CURM(3),CURJO(3),CURMO(3)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 3 K=1,IBUF(1)
      READ(LUNIT,REC=K+1)(FREC(NN),NN=1,19)
C  ------------ Rotate point
      DO 1 J=1,3
    1 XC(J)=FREC(J)-CENT(J)
      CALL MTMULT(XC,ROT,XA,1,3,3)
C  ------------ Rotate currents
      CALL CVTROT(CURJ,ROT,CURJO)
      CALL CVTROT(CURM,ROT,CURMO)
      DO 2 J=1,3
      XC(J)=FREC(J+4)
      FREC(J)=XA(J)+CENT(J)
      CURJ(J)=CURJO(J)
    2 CURM(J)=CURMA(J)
C  ------------ Rotate normal
      CALL MTMULT(XC,ROT,FREC(5),1,3,3)
    3 WRITE(LUNIT,REC=K+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE GEOROT(LUNIT,ROT,CENT,TRANSL)
C
C  Rotation of Geometry in File about point in space
C
C  LUNIT      Logical unit of currents and geometry file
C  ROT(3,3)   Rotation matrix
C  CENT(3)    Center of rotation
C  TRANSL(3)  Translation after rotation
C
      DIMENSION ROT(3,3),CENT(3),TRANSL(3),XC(3),XA(3),FREC(19),UN(3)
      INTEGER*4 IBUF(19)
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ---------- Loop on points
      DO 3 K=1,IBUF(1)
      READ(LUNIT,REC=K+1)(FREC(NN),NN=1,19)
C  ---------- Point relative to center of rotation
      DO 1 J=1,3
    1 XC(J)=FREC(J)-CENT(J)
C  ---------- Rotate position
      CALL MTMULT(XC,ROT,XA,1,3,3)
C  ---------- Rotate unit vector
      CALL MTMULT(FREC(5),ROT,UN,1,3,3)
      DO 2 J=1,3
      FREC(J)=XA(J)+CENT(J)+TRANSL(J)
    2 FREC(J+4)=UN(J)
    3 WRITE(LUNIT,REC=K+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE GREJC(XF,XS,PK,GEJ)
C
C  Complete: Near and far field
C
C  Dyadic Green's function between source current density: J
C  and electric field: E when multiplied by -j(2*pi*frequency)*mu
C  Dyadic Green's function between source current magnetic density: M
C  and the magnetic field: H when multiplied by -j(2*Pi*freq*epsilon)
C
C  XF(3)    Field point (units must match PK)
C  XS(3)    Source point (units must match PK)
C  PK       Propagation constant = 2*Pi/wavelength
C  GEJ(3,3) Free-space Dyadic Green's function (complex)
C
      DIMENSION XF(3),XS(3),RR(3,3)
      COMPLEX GEJ(3,3),CON,CONP,CONN
      DATA FPI/12.5663706/
      CALL RRMAT(XF,XS,RR,R)
      CON=2.*CMPLX(1./R,PK)/PK**2/R-1.
      CONN=CMPLX(1./(R*PK),1.)/(R*PK)
      PHASE=PK*R
      CONP=CMPLX(COS(PHASE),-SIN(PHASE))/FPI/R
      DO1I=1,3
      DO1J=1,3
      GEJ(I,J)=(CON+CONN)*RR(I,J)
      IF(I.EQ.J)GEJ(I,J)=GEJ(I,J)+1.-CONN
    1 GEJ(I,J)=CONP*GEJ(I,J)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE GRHJC(XF,XS,PK,GHJ)
C
C  Complete: Near and Far Field
C
C  Dyadic Green's function between source current density: J
C  and the magnetic field: H  when multiplied by j  or
C  Dyadic Green's function between source magnetic current density: M
C  and the electric field: E when multiplied by -j
C
C  XF(3)   Field point
C  XS(3)   Source point
C  PK      Propagation constant: units of XF, XS, PK should match
C          If the fields are expressed V/m, then the units should be m
C
      DIMENSION XF(3),XS(3),RCI(3,3)
      COMPLEX GHJ(3,3),CONP
      DATA FPI/12.5663706/
      CALL RCROSSI(XF,XS,RCI,R)
      PHASE=PK*R
      CONP=-CMPLX(1./R,PK)*CMPLX(COS(PHASE),-SIN(PHASE))/FPI/R
      DO1I=1,3
      DO1J=1,3
    1 GHJ(I,J)=CONP*RCI(I,J)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION HYBRF(XB)
C
C  Hybrid Mode F function to be Zeroed to find Radial Wave Number
C
C  XB     Radial Wavenumber 1/meters
C
      COMMON /HYBM/X
C
C  X(1)   Radius of Waveguide (meters)
C  X(2)   Wall Reactance (due to corrugations or dielectric slab)
C  X(3)   Free Space Propagation Constant 1/meters
C  X(4)   Circumferential mode number: n
C
      DIMENSION X(4)
      DATA ZZ/376.73/
      N=X(4)
      RP=XB*X(1)
      AJN=BESSJN(N,RP)
      AJP=BESJPR(N,RP)
C  ------------- Z axis wavenumber
      BKZ=SQRT(X(3)**2-XB**2)
C  ------------- Characteristic Equation
      HYBRF=RP*X(3)*AJP/(BKZ*N*AJN)+BKZ*N*AJN/
     1 XB/RP/(ZZ*AJN/X(2)-X(3)*AJP/XB)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE HYMK11(RADIUS,XS,AK0,AKP)
C
C  Hybrid Waveguide Mode Radial wave number for 11 mode
C
C  RADIUS   Waveguide radius
C  XS       Wall reactance
C  AK0      Free space propagation constant
C  AKP      Output Radial Wave Number
C
      DIMENSION XHYB(4)
      COMMON /HYBM/XHYB
C
C  XHYB(1)  Waveguide Radius
C  XHYB(2)  Wall Reactance
C  XHYB(3)  Free space propagation constant
C  XHYB(4)  Circumferential mode number
C
      EXTERNAL HYBRF
      DATA XACC/1.E-5/
      XHYB(1)=RADIUS
      XHYB(2)=XS
      XHYB(3)=AK0
      XHYB(4)=1
      DO 1 I=1,12
      X=(3.2-I*.1)/RADIUS
      IF(HYBRF(X).GT.0.)GOTO2
    1 CONTINUE
    2 AA=(3.2-I*.1)/RADIUS
      BB=(3.3-I*.1)/RADIUS
C ------ RTFLSP ref: Numerical Recipes in FORTRAN, 2nd ed. Cambridge
C        p. 349
      AKP=RTFLSP(HYBRF,AA,BB,XACC)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE MTMULT(A,B,C,NR,NN,NC)
C
C  Matrix Multiplication A x B = C
C
C  NR  Number of Rows of A and C
C  NN  Number of columns of A and Number of rows of B
C  NC  Number of columns of B and C
C
      DIMENSION A(NR,NN),B(NN,NC),C(NR,NC)
      DO1I=1,NR
      DO1J=1,NC
      C(I,J)=0.
      DO2K=1,NN
    2 C(I,J)=C(I,J)+A(I,K)*B(K,J)
    1 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE NFPATF(LUNIT,XC,BLOCK,XB,XF,EFIELD,HFIELD)
C
C  Near field pattern from currents in file
C
C  LUNIT     Logical unit of open file
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  XF(3)     Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMPLEX CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM,GEJ(3,3),GHJ(3,3)
      DIMENSION XS(3),XF(3),XC(3),XB(1),FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(1),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PK*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PK*CC*EPS)
      NCUR=IBUF(1)
      NCTYP=IBUF(2)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 5 I=1,NCUR
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      DO 2 J=1,3
    2 XS(J)=FREC(J)+XC(J)
C --------- Check for blockage
      IF(BLOCK(XB,XS,XF).EQ.0.)THEN
      CALL GREJC(XF,XS,PK,GEJ)
      CALL GRHJC(XF,XS,PK,GHJ)
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL CMTMUL(GEJ,CURJ,EF)
      CALL CMTMUL(GHJ,CURJ,HF)
      DO 3 J=1,3
      HFIELD(J)=HFIELD(J)+HF(J)
    3 EFIELD(J)=EFIELD(J)+EF(J)*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL CMTMUL(GEJ,CURM,HF)
      CALL CMTMUL(GHJ,CURM,EF)
      DO 4 J=1,3
      EFIELD(J)=EFIELD(J)-EF(J)
    4 HFIELD(J)=HFIELD(J)+HF(J)*CONM
      ENDIF
      ENDIF
    5 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE NFPATI(XC,XF,EFIELD,HFIELD)
C
C  Near field pattern from currents in common for image in gr.pl.
C  with dielectric slab to top surface at Z = 0
C
C  XC(3)     Position of center of currents
C  XF(3)     Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
      COMMON /DIELECT/ERS,THS,URS,ITEM
C
C  Dielectric slab common: /DIELECT/
C  ERS	  Dielectric constant (complex)
C	  ER*cmplx(1.,-(loss tangent)) or
C	  cmplx(ER,-(conductivity(S/m))/(2*pi*8.854185e-12*frequency))
C  THS	  Thickness (m)
C  URS	  Relative permeability
C  ITEM   If 1, use TEM approximation. 0, infinite slab, -1 actual
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM,GEJ(3,3),GHJ(3,3),EFIEL(3),HFIEL(3),HIN,EIN,
     2 ZSTM,ZSTE,GTM,GTE,ERS,PZM,ZMTE,ZMTM
      DIMENSION XS(3),XF(3),XC(3),XB(3),UI(3),PN(3),XBB(3)
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/,
     1 PN/0.,0.,1./,ZS/376.73/
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PKC*CC*EPS)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 5 I=1,NCUR
      DO 2 J=1,3
      EFIEL(J)=0.
      HFIEL(J)=0.
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    2 CURM(J)=CURMA(J,I)
      XS(3)=-XS(3)
C --------- Vector from image to field point
      CALL VLINC(1.,XF,-1.,XS,XB)
      XBL=SQRT(DOT(XB,XB))
      DO 6 J=1,3
    6 UI(J)=XB(J)/XBL
C --------- Plane of incidence normal: PN plane normal, UI Reflection
      CALL CROSS(PN,UI,XB)
      XBL=SQRT(DOT(XB,XB))
      DO 7 J=1,3
    7 XB(J)=XB(J)/XBL
      CALL GREJC(XF,XS,PKC,GEJ)
      CALL GRHJC(XF,XS,PKC,GHJ)
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL CMTMUL(GEJ,CURJ,EF)
      CALL CMTMUL(GHJ,CURJ,HF)
      DO 3 J=1,3
      HFIEL(J)=HFIEL(J)+HF(J)
    3 EFIEL(J)=EFIEL(J)+EF(J)*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL CMTMUL(GEJ,CURM,HF)
      CALL CMTMUL(GHJ,CURM,EF)
      DO 4 J=1,3
      EFIEL(J)=EFIEL(J)-EF(J)
    4 HFIEL(J)=HFIEL(J)+HF(J)*CONM
      ENDIF
      HIN=0.
      EIN=0.
C --------- Project Electric & magnetic fields on plane of incidence
      DO 8 J=1,3
      HIN=HIN+HFIEL(J)*XB(J)
    8 EIN=EIN+EFIEL(J)*XB(J)
C --------- Incident wave impedances
      ZTM=ZS*UI(3)
      ZTE=ZS/UI(3)
      PZM=PKC*CSQRT((ERS*URS-1.)+UI(3)**2)
      ZMTM=ZS*PZM/PKC/ERS
      ZMTE=ZS*PKC*URS/PZM
      IF(ITEM.EQ.1)THEN
      ZSTM=ZS*CSIN(PKC*THS*CSQRT(ERS))/CCOS(PKC*THS*CSQRT(ERS))*
     1 CMPLX(0.,-1.)/CSQRT(ERS)
      ZSTE=ZSTM
      ELSE IF(ITEM.EQ.-1)THEN
      ZSTM=ZMTM*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ZSTE=ZMTE*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ELSE IF(ITEM.EQ.0)THEN
      ZSTM=ZMTM
      ZSTE=ZMTE
      ENDIF
C --------- Find the reflection coefficients of two polarizations
      GTM=(ZTM-ZSTM)/(ZTM+ZSTM)
      GTE=(ZSTE-ZTE)/(ZSTE+ZTE)
C --------- Reduce reflected fields
      HIN=HIN*GTM
      EIN=EIN*GTE
C --------- Find reflected wave orthogonal polarization direction
      CALL CROSS(UI,XB,XBB)
C --------- Find total fields from projection on output polarizations
      DO 9 J=1,3
      EFIELD(J)=EFIELD(J)+XB(J)*EIN+XBB(J)*HIN*ZS
    9 HFIELD(J)=HFIELD(J)+XB(J)*HIN-XBB(J)*EIN/ZS
    5 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE NFPATR(XC,BLOCK,XB,XF,EFIELD,HFIELD)
C
C  Near field pattern from currents in common
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  XF(3)     Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM,GEJ(3,3),GHJ(3,3)
      DIMENSION XS(3),XF(3),XC(3),XB(1)
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PKC*CC*EPS)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 5 I=1,NCUR
      DO 2 J=1,3
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    2 CURM(J)=CURMA(J,I)
C --------- Check for blockage
      IF(BLOCK(XB,XS,XF).EQ.0.)THEN
      CALL GREJC(XF,XS,PKC,GEJ)
      CALL GRHJC(XF,XS,PKC,GHJ)
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL CMTMUL(GEJ,CURJ,EF)
      CALL CMTMUL(GHJ,CURJ,HF)
      DO 3 J=1,3
      HFIELD(J)=HFIELD(J)+HF(J)
    3 EFIELD(J)=EFIELD(J)+EF(J)*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL CMTMUL(GEJ,CURM,HF)
      CALL CMTMUL(GHJ,CURM,EF)
      DO 4 J=1,3
      EFIELD(J)=EFIELD(J)-EF(J)
    4 HFIELD(J)=HFIELD(J)+HF(J)*CONM
      ENDIF
      ENDIF
    5 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE NORMP(P,FOC,RNORM)
C
C  Unit Normal to Paraboloidal Reflector at Point P, Focal Length FOC
C
      DIMENSION RNORM(1),P(1)
      AL=SQRT(P(1)**2+P(2)**2+4.*FOC**2)
      RNORM(1)=-P(1)/AL
      RNORM(2)=-P(2)/AL
      RNORM(3)=2.*FOC/AL
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE NRPATF(LUNIT,XC,BLOCK,XB,XF,EFIELD,HFIELD)
C
C  Radiative Near field pattern from currents in file
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  XF        Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMPLEX CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM
      DIMENSION XS(3),XF(3),XC(3),XB(1),FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PK*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PK*CC*EPS)
      NCUR=IBUF(1)
      NCTYP=IBUF(2)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 7 I=1,NCUR
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      DO 2 J=1,3
    2 XS(J)=FREC(J)+XC(J)
C --------- Check for ray blockage
      IF(BLOCK(XB,XS,XF).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJN(XF,XS,PK,CURJ,EF)
      DO 3 J=1,3
    3 EFIELD(J)=EFIELD(J)+EF(J)*CONJ
      CALL VGRHJN(XF,XS,PK,CURJ,HF)
      DO 4 J=1,3
    4 HFIELD(J)=HFIELD(J)+HF(J)
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGREJN(XF,XS,PK,CURM,HF)
      DO 5 J=1,3
    5 HFIELD(J)=HFIELD(J)+HF(J)*CONM
      CALL VGRHJN(XF,XS,PK,CURM,EF)
      DO 6 J=1,3
    6 EFIELD(J)=EFIELD(J)-EF(J)
      ENDIF
      ENDIF
    7 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE NRPATR(XC,BLOCK,XB,XF,EFIELD,HFIELD)
C
C  Radiative Near field pattern from currents in common
C
C  XC(3)     Position of center of currents
C  BLOCK     Blockage function (external) = 1 when blocked
C  XB        Array of variables for blockage function
C  XF        Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM
      DIMENSION XS(3),XF(3),XC(3),XB(1)
      EXTERNAL BLOCK
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PKC*CC*EPS)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 7 I=1,NCUR
      DO 2 J=1,3
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    2 CURM(J)=CURMA(J,I)
C --------- Check for ray blockage
      IF(BLOCK(XB,XS,XF).EQ.0)THEN
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL VGREJN(XF,XS,PKC,CURJ,EF)
      DO 3 J=1,3
    3 EFIELD(J)=EFIELD(J)+EF(J)*CONJ
      CALL VGRHJN(XF,XS,PKC,CURJ,HF)
      DO 4 J=1,3
    4 HFIELD(J)=HFIELD(J)+HF(J)
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL VGREJN(XF,XS,PKC,CURM,HF)
      DO 5 J=1,3
    5 HFIELD(J)=HFIELD(J)+HF(J)*CONM
      CALL VGRHJN(XF,XS,PKC,CURM,EF)
      DO 6 J=1,3
    6 EFIELD(J)=EFIELD(J)-EF(J)
      ENDIF
      ENDIF
    7 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE PABGEO(XMIN,XMAX,YMIN,YMAX,FOCUS,BLOCK,XB,
     1 VP,NX,NY,LUNIT)
C
C  Paraboloidal Reflector Geometry for Currents File
C  using rectangular grid and external blockage function for rim
C
C  XMIN    Minimum X axis position of rim
C  XMAX    Maximum X axis position of rim
C  YMIN    Minimum Y axis position of rim
C  YMAX    Maximum Y axis position of rim
C  FOCUS   Focal length
C  BLOCK   External blockage function to determine rim shape
C  XB( )   Blockage function variables
C  VP(3)   Location of parent paraboloid vertex
C  Note:   Paraboloid axis along Z-axis
C  NX      Number of points in X-axis integrals
C  NY      Number of points in Y-axis integrals
C  LUNIT   Logical unit of random access file for currents
C
      DIMENSION VP(1),FREC(19),PP(3),XB(1),VR(3)
      INTEGER*4 IBUF(19)
      EXTERNAL BLOCK
      DATA VR/0.,0.,1./
      HX=(XMAX-XMIN)/NX
      HY=(YMAX-YMIN)/NY
      KREC=1
C  ------------- Loop over X-axis
      DO 2 J=1,NX
      PP(1)=XMIN+HX*(J-.5)
      DO 1 I=1,NY
      PP(2)=YMIN+HY*(I-.5)
      PP(3)=-1.
      IF(BLOCK(XB,PP,VR).EQ.1.)THEN
C  ------------- Point within rim
      RP=SQRT(PP(1)**2+PP(2)**2)
      PP(3)=RP*RP/4./FOCUS
C  ------------- Find unit normal
      CALL NORMP(PP,FOCUS,FREC(5))
C  ------------- Adjust area
      FREC(4)=HX*HY/FREC(7)
      CALL VLINC(1.,VP,1.,PP,FREC)
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
      ENDIF
    1 CONTINUE
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE PARGEO(DIA,FOCUS,OFFSET,VP,ALINC,LUNIT)
C
C  Offset Paraboloidal Reflector Geometry for Currents File
C  Polar Grid
C
C  DIA     Diameter of projected reflector
C  FOCUS   Focal length
C  OFFSET  Offset (center of circular aperture in X-Y plane)
C  VP(3)   Location of parent paraboloid vertex
C  ALINC   Length increment in aperture plane for current patches
C  Note:   Paraboloid axis along Z-axis
C  LUNIT   Logical unit of random access file for currents
C
      DIMENSION VP(1),FREC(19),PP(3),OFFSET(2)
      INTEGER*4 IBUF(19)
      DATA PI/3.14159654/
      NR=DIA/ALINC/2.+.5
      HR=DIA/2./NR
      KREC=1
C  ------------- Loop over radius
      DO 2 J=1,NR
      RAD=(FLOAT(J-1)+.5)*HR
C  ------------- Find differential area on aperture plane
      R1=RAD-HR/2.
      R2=RAD+HR/2.
      AREA=(R2**2-R1**2)/2.
      NP=2.*PI*RAD/ALINC+.5
      NP=NP/4
      NP=(NP+1)*4
      HP=2.*PI/NP
C  ------------- Loop over Phi
      DO 1 I=1,NP
      PH=FLOAT(I-1)*HP
      PP(1)=OFFSET(1)+RAD*COS(PH)
      PP(2)=OFFSET(2)+RAD*SIN(PH)
      RP=SQRT(PP(1)**2+PP(2)**2)
      PP(3)=RP*RP/4./FOCUS
C  ------------- Find unit normal
      CALL NORMP(PP,FOCUS,FREC(5))
C  ------------- Adjust area
      FREC(4)=AREA*HP/FREC(7)
      CALL VLINC(1.,VP,1.,PP,FREC)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION PATBEAM(BL,BN,NAPPR)
C
C  Pattern Approximation  I: E = cos(Theta/2)**N  Beamwidth (degrees)
C                        II: E = cos(Theta)**N
C
C  BL      Beamwidth level dB
C  BN      Pattern exponent
C  NAPPR   Approximation number
C
      DATA TR/.01745329/
      PATBEAM=4.*ACOS(10.**(-ABS(BL)/(20.*BN)))/NAPPR/TR
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION PATEXP(BW,BL,NAPPR)
C
C  Pattern Approximation  I: E = cos(Theta/2)**N Pattern Exponent
C                        II: E = cos(Theta)**N   Pattern Exponent
C
C  BWE     Beamwidth  (degrees)
C  BLE     Beamwidth level (dB)
C  NAPPR   Approximation number
C
      DATA TR/.01745329/
      CCA=COS(BW*TR*.25*NAPPR)
      IF(CCA.LT.0)THEN
C --------------- Impossible beamwidth
      PATEXP=0
      ELSE
      PATEXP=-ABS(BL)/(20.*ALOG10(CCA))
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE PATIND(INST,THETA,PHI,ET,EP)
C
C  Interpolation from multiple patterns
C  using bilinear interpolation
C
C  INST    - 1 Initialize:
C            2 Return pattern value
C  THETA       Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  PHI         Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  ET          Complex electric field V/m @ 1 m, 1 w input Theta
C  EP          Complex electric field V/m @ 1 m, 1 w input Phi
C
      DIMENSION SP(3),SR(3)
      COMPLEX PATT(16380),PATP(16380),ET,EP,Y(4),X(4)
      DATA TR/.01745329/,GCONS/.1826374/
      IF(INST.LT.2)THEN
C
C  Reads ASCII data file LU = 31, open before calling
C
C ------- Initialize
C  1st record:
C  Type: [1 Conic, 2 Great Circle], # Scans, # Points in scan
C  Type = -2 if Theta > 180 or Theta < 0 included
C
C  2nd record:  Step angles: Start, Step; Scan angles: Start, Step
C  3rd record & following: (Theta) Ampl. dB, Phase, (Phi) Ampl. Phase
C
      READ(31,*)ITYPE,NSCAN,NPOINT
      READ(31,*)STS,STP,SCS,SCP
      DO 2 I=1,NSCAN
      DO 1 J=1,NPOINT
      READ(31,*)AMT,PHT,AMP,PHP
      N=(I-1)*NPOINT+J
      PATT(N)=10.**((AMT+THETA)/20.)*CMPLX(COS(PHT*TR),
     1 SIN(PHT*TR))/GCONS
    1 PATP(N)=10.**((AMP+THETA)/20.)*CMPLX(COS(PHP*TR),
     1 SIN(PHP*TR))/GCONS
    2 CONTINUE
      VT=10.**(THETA/20.)/GCONS
      VP=10.**(PHI/20.)/GCONS
      ELSE
C -------- Return value
      SP(1)=1.
      SP(2)=TR*THETA
      SP(3)=TR*PHI
C -------- Convert to rectangular and back to spherical
      CALL ARADS(SP,SR)
      CALL RETSP(SR,SP)
      IF(ITYPE.EQ.1)THEN
C -------- Conical patterns
      THH=SP(2)/TR
      PHH=SP(3)/TR
      ELSE
C -------- Great circle patterns
      THH=SP(3)/TR
      PHH=SP(2)/TR
      IF(THH.LT.0..AND.ITYPE.EQ.-2)THEN
      PHH=360.-PHH
      THH=180.+THH
      ENDIF
      ENDIF
      IF(ITYPE.NE.2)NM=360./SCP+.1
      IF(ITYPE.EQ.2)NM=180./SCP+.1
      DSC=PHH-SCS
      IF(ITYPE.NE.2)DSC=AMOD(DSC,360.)
      IF(ITYPE.EQ.2.AND.ABS(DSC-180.).GT..02)DSC=AMOD(DSC,180.)
      DSC=DSC/SCP
      IF(DSC.LT.0.)DSC=DSC+NM
      NP=DSC
      T=DSC-NP
      NP=NP+1
      IF(NP.EQ.NM)THEN
      NP=NP-1
      T=T+1
      ENDIF
      IF(ITYPE.EQ.2)NM=360./STP+.1
      IF(ITYPE.NE.2)NM=180./STP+.1
      DST=THH-STS
      IF(ITYPE.EQ.2)DST=AMOD(DST,360.)
      IF(ITYPE.NE.2.AND.ABS(DST-180.).GT..02)DST=AMOD(DST,180.)
      DST=DST/STP
      IF(DST.LT.0.)DST=DST+NM
      NT=DST
      U=DST-NT
      NT=NT+1
      IF(ITYPE.EQ.1)TIN=STS+(NT-1)*STP
      IF(IABS(ITYPE).EQ.2)TIN=SCS+(NP-1)*SCP
      SGN=SIGN(1.,SIN(TIN*TR))
      DO 3 I=1,4
      Y(I)=0.
    3 X(I)=0.
C -------- Pick points for bilinear interpolation
      IF(NP.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+(NT-1)*NPOINT+2
      Y(1)=PATT(NN)
      X(1)=PATP(NN)
      IF(NP+1.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+1+(NT-1)*NPOINT+2
      Y(2)=PATT(NN)
      X(2)=PATP(NN)
      ENDIF
      ENDIF
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+NT*NPOINT+2
      Y(4)=PATT(NN)
      X(4)=PATP(NN)
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+1+NT*NPOINT+2
      Y(3)=PATT(NN)
      X(3)=PATP(NN)
      ENDIF
      ENDIF
      ET=((1.-T)*(1.-U)*Y(1)+T*(1.-U)*Y(2)+T*U*Y(3)+(1.-T)*U*Y(4))*VT
      EP=((1.-T)*(1.-U)*X(1)+T*(1.-U)*X(2)+T*U*X(3)+(1.-T)*U*X(4))*VP
      ET=ET*SGN
      EP=EP*SGN
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END


      SUBROUTINE PATINF(LUNIT,INST,THETA,PHI,ET,EP)
C
C  Interpolation from multiple patterns
C  using bilinear interpolation from file with Theta & Phi components
C  This routine requires static storage
C  It can use multiple files if they have the same structure and use
C  the same multipliers
C
C  INST    - 1 Initialize:
C            2 Return pattern value
C  THETA       Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  PHI         Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  ET          Complex electric field V/m @ 1 m, 1 w input Theta
C  EP          Complex electric field V/m @ 1 m, 1 w input Phi
C
      DIMENSION SP(3),SR(3)
      INTEGER*4 IBUF(4)
      COMPLEX ET,EP,Y(4),X(4)
      DATA TR/.01745329/,GCONS/.1826374/
      IF(INST.LT.2)THEN
C
C  Reads random access data file LU = LUNIT, open before calling
C
C ------- Initialize
C  1st record:
C  Type: [1 Conic, 2 Great Circle], # Scans, # Points in scan
C  Type = -2 if Theta > 180 or Theta < 0 included
C
C  2nd record:  Step angles: Start, Step; Scan angles: Start, Step
C  3rd record & following: Theta, Phi Components (Complex voltages)
C
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,4)
      ITYPE=IBUF(1)
      NSCAN=IBUF(2)
      NPOINT=IBUF(3)
      READ(LUNIT,REC=2)STS,STP,SCS,SCP
      VT=10.**(THETA/20.)/GCONS
      VP=10.**(PHI/20.)/GCONS
      ELSE
C -------- Return value
      SP(1)=1.
      SP(2)=TR*THETA
      SP(3)=TR*PHI
C -------- Convert to rectangular and back to spherical
      CALL ARADS(SP,SR)
      CALL RETSP(SR,SP)
      IF(ITYPE.EQ.1)THEN
C -------- Conical patterns
      THH=SP(2)/TR
      PHH=SP(3)/TR
      ELSE
C -------- Great circle patterns
      THH=SP(3)/TR
      PHH=SP(2)/TR
      IF(THH.LT.0..AND.ITYPE.EQ.-2)THEN
      PHH=360.-PHH
      THH=180.+THH
      ENDIF
      ENDIF
      IF(ITYPE.NE.2)NM=360./SCP+.1
      IF(ITYPE.EQ.2)NM=180./SCP+.1
      DSC=PHH-SCS
      IF(ITYPE.NE.2)DSC=AMOD(DSC,360.)
      IF(ITYPE.EQ.2.AND.ABS(DSC-180.).GT..02)DSC=AMOD(DSC,180.)
      DSC=DSC/SCP
      IF(DSC.LT.0.)DSC=DSC+NM
      NP=DSC
      T=DSC-NP
      NP=NP+1
      IF(NP.EQ.NM)THEN
      NP=NP-1
      T=T+1
      ENDIF
      IF(ITYPE.EQ.2)NM=360./STP+.1
      IF(ITYPE.NE.2)NM=180./STP+.1
      DST=THH-STS
      IF(ITYPE.EQ.2)DST=AMOD(DST,360.)
      IF(ITYPE.NE.2.AND.ABS(DST-180.).GT..02)DST=AMOD(DST,180.)
      DST=DST/STP
      IF(DST.LT.0.)DST=DST+NM
      NT=DST
      U=DST-NT
      NT=NT+1
      IF(ITYPE.EQ.1)TIN=STS+(NT-1)*STP
      IF(IABS(ITYPE).EQ.2)TIN=SCS+(NP-1)*SCP
      SGN=SIGN(1.,SIN(TIN*TR))
      DO 3 I=1,4
      Y(I)=0.
    3 X(I)=0.
C -------- Pick points for bilinear interpolation
      IF(NP.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+(NT-1)*NPOINT+2
      READ(LUNIT,REC=NN)Y(1),X(1)
      IF(NP+1.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+1+(NT-1)*NPOINT+2
      READ(LUNIT,REC=NN)Y(2),X(2)
      ENDIF
      ENDIF
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+NT*NPOINT+2
      READ(LUNIT,REC=NN)Y(4),X(4)
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+1+NT*NPOINT+2
      READ(LUNIT,REC=NN)Y(3),X(3)
      ENDIF
      ENDIF
      ET=((1.-T)*(1.-U)*Y(1)+T*(1.-U)*Y(2)+T*U*Y(3)+(1.-T)*U*Y(4))*VT
      EP=((1.-T)*(1.-U)*X(1)+T*(1.-U)*X(2)+T*U*X(3)+(1.-T)*U*X(4))*VP
      ET=ET*SGN
      EP=EP*SGN
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END


      SUBROUTINE PATINT(INST,THETA,PHI,VAL)
C
C  Interpolation from multiple patterns
C  using bilinear interpolation
C
C  INST    - 1 Initialize:
C            2 Return pattern value
C  THETA       Pattern Angle (deg) (Value to add to bias to gain
C              on initialization dB)
C  PHI	       Pattern Angle (deg)
C  VAL	       Complex electric field V/m @ 1 m, 1 w input
C
      DIMENSION SP(3),SR(3)
      COMPLEX PATT(16380),Y(4),VAL
      DATA TR/.01745329/,GCONS/.1826374/
      IF(INST.LT.2)THEN
C
C  Reads ASCII data file LU = 31, open before calling
C
C ------- Initialize
C  1st record:
C  Type: [1 Conic, 2 Great Circle], # Scans, # Points in scan
C  Type = -2 if Theta > 180 or Theta < 0 included
C
C  2nd record:  Step angles: Start, Step; Scan angles: Start, Step
C  3rd record & following: Ampl. dB, Phase
C
      READ(31,*)ITYPE,NSCAN,NPOINT
      READ(31,*)STS,STP,SCS,SCP
      DO 2 I=1,NSCAN
      DO 1 J=1,NPOINT
      READ(31,*)AMT,PHT
      N=(I-1)*NPOINT+J
    1 PATT(N)=10.**((AMT+THETA)/20.)*CMPLX(COS(PHT*TR),
     1 SIN(PHT*TR))/GCONS
    2 CONTINUE
      ELSE
C -------- Return value
      SP(1)=1.
      SP(2)=TR*THETA
      SP(3)=TR*PHI
C -------- Convert to rectangular and back to spherical
      CALL ARADS(SP,SR)
      CALL RETSP(SR,SP)
      IF(ITYPE.EQ.1)THEN
C -------- Conical patterns
      THH=SP(2)/TR
      PHH=SP(3)/TR
      ELSE
C -------- Great circle patterns
      THH=SP(3)/TR
      PHH=SP(2)/TR
      IF(THH.LT.0..AND.ITYPE.EQ.-2)THEN
      PHH=360.-PHH
      THH=180.+THH
      ENDIF
      ENDIF
      IF(ITYPE.NE.2)NM=360./SCP+.1
      IF(ITYPE.EQ.2)NM=180./SCP+.1
      DSC=PHH-SCS
      IF(ITYPE.NE.2)DSC=AMOD(DSC,360.)
      IF(ITYPE.EQ.2.AND.ABS(DSC-180.).GT..02)DSC=AMOD(DSC,180.)
      DSC=DSC/SCP
      IF(DSC.LT.0.)DSC=DSC+NM
      NP=DSC
      T=DSC-NP
      NP=NP+1
      IF(NP.EQ.NM)THEN
      NP=NP-1
      T=T+1
      ENDIF
      IF(ITYPE.EQ.2)NM=360./STP+.1
      IF(ITYPE.NE.2)NM=180./STP+.1
      DST=THH-STS
      IF(ITYPE.EQ.2)DST=AMOD(DST,360.)
      IF(ITYPE.NE.2.AND.ABS(DST-180.).GT..02)DST=AMOD(DST,180.)
      DST=DST/STP
      IF(DST.LT.0.)DST=DST+NM
      NT=DST
      U=DST-NT
      NT=NT+1
      IF(ITYPE.EQ.1)TIN=STS+(NT-1)*STP
      IF(IABS(ITYPE).EQ.2)TIN=SCS+(NP-1)*SCP
      SGN=SIGN(1.,SIN(TIN*TR))
      DO 3 I=1,4
    3 Y(I)=0.
C -------- Pick points for bilinear interpolation
      IF(NP.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+(NT-1)*NPOINT+2
      Y(1)=PATT(NN)
      IF(NP+1.LE.NPOINT.AND.NT-1.LE.NSCAN)THEN
      NN=NP+1+(NT-1)*NPOINT+2
      Y(2)=PATT(NN)
      ENDIF
      ENDIF
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+NT*NPOINT+2
      Y(4)=PATT(NN)
      IF(NP+1.LE.NPOINT.AND.NT.LT.NSCAN)THEN
      NN=NP+1+NT*NPOINT+2
      Y(3)=PATT(NN)
      ENDIF
      ENDIF
      VAL=((1.-T)*(1.-U)*Y(1)+T*(1.-U)*Y(2)+T*U*Y(3)+(1.-T)*U*Y(4))
      VAL=VAL*SGN
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END


      SUBROUTINE PATROT(ROT,VR,VT,VP,THETA,PHI,VTP,VPP)
C
C  Rotates Pattern direction in prime coordinates to rotated
C  antenna coordinates
C
C  ROT(3,3)   Rotation matrix
C  VR(3)      Pattern direction unit vector
C  VT(3)      Theta unit vector for VR direction
C  VP(3)      Phi unit vector for VR direction
C
C  THETA      Pattern direction in rotated antenna coordinates
C  PHI        Pattern direction in rotated antenna (radians)
C  VTP(3)     Direction of Theta component in rotated coordinates
C  VPP(3)     Direction of  Phi  component in rotated coordinates
C
      DIMENSION ROT(3,3),VR(3),VT(3),VP(3),VTP(3),VPP(3),XX(3),SP(3)
      CALL MTMULT(ROT,VR,XX,3,3,1)
      CALL RETSP(XX,SP)
      THETA=SP(2)
      PHI=SP(3)
      CALL MTMULT(ROT,VT,VTP,3,3,1)
      CALL MTMULT(ROT,VP,VPP,3,3,1)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE PINTS(PL,UL,PP,PN,T,P,NIS)
C
C  Intersection of Unbounded plane and line expressed as point and
C  unit vector
C
C  PL(3)   Input point on line
C  UL(3)   Input unit vector direction of line
C  PP(3)   Input Point on plane
C  PN(3)   Input unit vector normal to plane
C  T       Output distance from point PL to plane
C  P(3)    Output intersection point
C  NIS     Output = -1 if no intersection
C
      DIMENSION PL(3),UL(3),PP(3),PN(3),P(3)
      IF(DOT(PN,UL).NE.0.)THEN
      NIS=1
      T=(DOT(PN,PP)-DOT(PN,PL))/DOT(PN,UL)
      DO1I=1,3
    1 P(I)=PL(I)+T*UL(I)
      ELSE
      NIS=-1
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE PLBGEO(XMIN,XMAX,YMIN,YMAX,BLOCK,XB,
     1 VP,NX,NY,LUNIT)
C
C  Flat Plate Geometry for Currents File
C  using rectangular grid and external blockage function for rim
C
C  XMIN    Minimum X axis position of rim
C  XMAX    Maximum X axis position of rim
C  YMIN    Minimum Y axis position of rim
C  YMAX    Maximum Y axis position of rim
C  BLOCK   External blockage function to determine rim shape
C  XB( )   Blockage function variables
C  VP(3)   Location of center
C  Note:   Normal along Z-axis
C  NX      Number of points in X-axis integrals
C  NY      Number of points in Y-axis integrals
C  LUNIT   Logical unit of random access file for currents
C
      DIMENSION VP(1),FREC(19),PP(3),XB(1),VR(3)
      INTEGER*4 IBUF(19)
      EXTERNAL BLOCK
      DATA VR/0.,0.,1./
      HX=(XMAX-XMIN)/NX
      HY=(YMAX-YMIN)/NY
      FREC(4)=HX*HY
      FREC(5)=0.
      FREC(6)=0.
      FREC(7)=1.
      KREC=1
C  ------------- Loop over X-axis
      DO 2 J=1,NX
      PP(1)=XMIN+HX*(J-.5)
      DO 1 I=1,NY
      PP(2)=YMIN+HY*(I-.5)
      PP(3)=-1.
      IF(BLOCK(XB,PP,VR).EQ.1.)THEN
C  ------------- Point within rim
      PP(3)=0.
      CALL VLINC(1.,VP,1.,PP,FREC)
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
      ENDIF
    1 CONTINUE
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION POLBKF(XB,XS,VR)
C
C  Polygon disk blockage function for far field
C
C  XB         Blockage function vector
C      1      Number of vertices
C      2 - 4  Unit normal
C      5 -    Vertices
C
C  XS(3)      Source point
C  VR(3)      Radial unit vector
C
      DIMENSION XB(1),XS(1),VR(1),PT(3)
      POLBKF=0.
      NV=XB(1)
      CALL PINTS(XS,VR,XB(5),XB(2),T,PT,NIS)
      IF(NIS.EQ.-1.OR.T.LT.0.)RETURN
      IF(POLYIN(PT,XB(5),NV,XB(2)).EQ.-1.)RETURN
      POLBKF=1.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION POLBKN(XB,XS,XF)
C
C  Polygon disk blockage function for near field
C
C  XB         Blockage function vector
C      1      Number of vertices
C      2 - 4  Unit normal
C      5 -    Vertices
C
C  XS(3)      Source point
C  VR(3)      Radial unit vector
C
      DIMENSION XB(1),XS(1),XF(1),PT(3),FS(3)
      CALL VLINC(-1.,XS,1.,XF,FS)
      FSL=SQRT(DOT(FS,FS))
      DO 1 I=1,3
    1 FS(I)=FS(I)/FSL
      POLBKN=0.
      NV=XB(1)
      CALL PINTS(XS,FS,XB(5),XB(2),T,PT,NIS)
      IF(NIS.EQ.-1.OR.T.LT.0.)RETURN
      TEST=POLYIN(PT,XB(5),NV,XB(2))
      IF(TEST.EQ.-1.)RETURN
      IF(T.GT.FSL)RETURN
      POLBKN=1.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE POLBKP(VT,NV,CT,ROT,XB)
C
C  Polygon Disk Blockage Preparation
C
C  VT(3,NV)   Vertices of polygon ordered CCW around Normal (in
C             X-Y plane)
C  NV         Number of vertices
C  CT(3)      Center of poylgon after rotation
C  ROT(3,3)   Rotation matrix (polygon rotated off X-Y plane)
C  XB         Blockage function vector
C      1      Number of vertices
C      2 - 4  Unit normal
C      5 -    Vertices
C
      DIMENSION VT(1),CT(1),ROT(3,3),XB(1),AN(3)
      XB(1)=NV
      CALL POLYNM(VT,AN)
      CALL MTMULT(AN,ROT,XB(2),1,3,3)
      DO 1 I=1,NV
      K=3*(I-1)+1
      KK=3*(I-1)+5
      CALL MTMULT(VT(K),ROT,XB(KK),1,3,3)
    1 CALL VLINC(1.,XB(KK),1.,CT,XB(KK))
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION POLYIN(PT,VT,NV,AN)
C
C  Whether point PT, an intersection with the planar polygon, is
C  inside (+1) or outside (-1) the polygon
C
C  PT(3)     Intersection point with plane
C  VT(3,NT)  Vertices of the polygon ordered CCW around Normal
C  NV        Number of vertices
C  AN(3)     Plane unit normal
C
      DIMENSION PT(1),VT(1),V1(3),V2(3),AN(3),XX(3)
      DATA PI/3.141592654/
      POLYIN=1
      THMT=0.
      DO 2 I=1,NV-1
      K=3*(I-1)
      KK=3*I
      DO 1 J=1,3
      V1(J)=VT(K+J)-PT(J)
    1 V2(J)=VT(KK+J)-PT(J)
      CALL CROSS(V1,V2,XX)
    2 THMT=THMT+ATAN2(DOT(XX,AN),DOT(V1,V2))
      K=3*(NV-1)
      DO 3 J=1,3
      V1(J)=VT(K+J)-PT(J)
    3 V2(J)=VT(J)-PT(J)
      CALL CROSS(V1,V2,XX)
      THMT=THMT+ATAN2(DOT(XX,AN),DOT(V1,V2))
      IF(ABS(THMT).LT.PI)POLYIN=-1
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE POLYNM(VT,AN)
C
C  Unit normal to planar polygon
C
C  VT(3,NT)   Vertices of polygon
C  AN(3)      Returned unit normal
C
C  It is assumed that the vertices are ordered CCW around the normal
C
      DIMENSION VT(1),AN(1),V1(3),V2(3)
      DO 1 I=1,3
      V1(I)=VT(I+6)-VT(I+3)
    1 V2(I)=VT(I)-VT(I+3)
      CALL CROSS(V1,V2,AN)
      AL=SQRT(DOT(AN,AN))
      DO 2 I=1,3
    2 AN(I)=AN(I)/AL
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE PYRGEO(HEIGHT,ALINC,XPB,LUNIT)
C
C  Pyramid Geometry Generation
C
C  HEIGHT   Height of pyramid above plane
C  ALINC    Minimum length along edges
C  XPB      Blockage of array of base polygon
C  LUNIT    Logical unit of random access file for currents
C
      DIMENSION XPB(1),PP1(3),PP2(3),PP3(3),TP1(3),TP2(3),TP3(3),
     1 FREC(19),CENT(3)
      INTEGER*4 IBUF(19)
      NV=XPB(1)+.1
      CENT(1)=0.
      CENT(2)=0.
      CENT(3)=0.
C  ------------- Find center point of polygon
      DO 1 I=1,NV
      DO 1 J=1,3
    1 CENT(J)=CENT(J)+XPB(3*I+J+1)/NV
C  ------------- Find vertex of pyramid
      CALL VLINC(1.,CENT,HEIGHT,XPB(2),PP1)
C  ------------- Loop on base vertices
      KREC=1
      DO 10 I=1,NV
      K=MOD(I,NV)+1
C  ------------- Find vertices of triangle
      DO 2 J=1,3
      PP2(J)=XPB(3*I+J+1)+ALINC*XPB(J+1)
      PP3(J)=XPB(3*K+J+1)+ALINC*XPB(J+1)
      TP1(J)=PP2(J)-PP1(J)
      TP2(J)=PP3(J)-PP1(J)
    2 TP3(J)=PP3(J)-PP2(J)
C  ------------- Find patches normal to plane
      EDGE=SQRT(DOT(TP3,TP3))
      IS3=EDGE/ALINC+1
      FREC(4)=ALINC*EDGE/IS3
      CALL CROSS(TP3,XPB(2),FREC(5))
      AN=SQRT(DOT(FREC(5),FREC(5)))
      DO 3 J=1,3
    3 FREC(J+4)=FREC(J+4)/AN
      DO 4 II=1,IS3
      FAC=(FLOAT(II)-.5)/FLOAT(IS3)
      CALL VLINC(1.,PP2,FAC,TP3,FREC)
      ALC=-ALINC/2.
      CALL VLINC(1.,FREC,ALC,XPB(2),FREC)
      KREC=KREC+1
    4 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
C  ------------- Find unit normal to plane
      CALL CROSS(TP1,TP2,FREC(5))
      AN=SQRT(DOT(FREC(5),FREC(5)))
      DO 5 J=1,3
    5 FREC(J+4)=FREC(J+4)/AN
      IS1=SQRT(DOT(TP1,TP1))/ALINC+1
      IS2=SQRT(DOT(TP2,TP2))/ALINC+1
      NSUB=MAX0(IS1,IS2,IS3)
C  ------------ Subdivide triangle
      DO 9 II=0,NSUB-1
      DO 8 JJ=0,II
C  ------------ Righted triangles
      DO 6 KK=1,3
      TP1(KK)=PP1(KK)+II*(PP2(KK)-PP1(KK))/NSUB
     1 +JJ*(PP3(KK)-PP2(KK))/NSUB
      TP2(KK)=PP1(KK)+(II+1)*(PP2(KK)-PP1(KK))/NSUB
     1 +JJ*(PP3(KK)-PP2(KK))/NSUB
    6 TP3(KK)=PP1(KK)+(II+1)*(PP2(KK)-PP1(KK))/NSUB
     1 +(JJ+1)*(PP3(KK)-PP2(KK))/NSUB
      CALL TRIAN(TP1,TP2,TP3,FREC(1),FREC(4))
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
      IF(II.GT.0.AND.JJ.LT.II)THEN
C  ------------ Upside down triangles
      DO 7 KK=1,3
      TP1(KK)=PP1(KK)+II*(PP2(KK)-PP1(KK))/NSUB
     1 +JJ*(PP3(KK)-PP2(KK))/NSUB
      TP2(KK)=PP1(KK)+II*(PP2(KK)-PP1(KK))/NSUB
     1 +(JJ+1)*(PP3(KK)-PP2(KK))/NSUB
    7 TP3(KK)=PP1(KK)+(II+1)*(PP2(KK)-PP1(KK))/NSUB
     1 +(JJ+1)*(PP3(KK)-PP2(KK))/NSUB
      CALL TRIAN(TP1,TP2,TP3,FREC(1),FREC(4))
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
      ENDIF
    8 CONTINUE
    9 CONTINUE
   10 CONTINUE
      IBUF(1)=KREC-1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      RETURN
      END
      SUBROUTINE TRIAN(P1,P2,P3,PC,AREA)
C
C  Triangle in space
C
C  P1, P2, P3  Vertices (input)
C  PC          Center of area
C  AREA        Area of triangle
C
      DIMENSION P1(3),P2(3),P3(3),PC(1)
      D1=SQRT(DOT(P1,P2))
      D2=SQRT(DOT(P2,P3))
      D3=SQRT(DOT(P3,P1))
      S=D1+D2+D3
      AREA=SQRT(S*(S-D1)*(S-D2)*(S-D3))
      DO 1 I=1,3
    1 PC(I)=(P1(I)+P2(I)+P3(I))/3.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RCROSSI(XF,XS,RCI,R)
C
C  Matrix R x I given field point: XF(3) and source point: XS(3)
C
      DIMENSION XF(3),XS(3),DD(3),RCI(3,3)
      R=0.
      DO1I=1,3
      RCI(I,I)=0.
      DD(I)=XF(I)-XS(I)
    1 R=R+DD(I)**2
      R=SQRT(R)
      RCI(1,2)=-DD(3)/R
      RCI(1,3)=DD(2)/R
      RCI(2,3)=-DD(1)/R
      RCI(2,1)=-RCI(1,2)
      RCI(3,1)=-RCI(1,3)
      RCI(3,2)=-RCI(2,3)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RCSPAT(ROT,NAP,THETA,PHI,BNE,BNH,POL,ETHETA,EPHI)
C
C  Rotated
C  Pattern approximation  I: E = cos(Theta/2)**N
C                        II: E = cos(Theta)**N
C
C  ROT(3,3) Rotation matrix
C  NAP      Pattern approximation number
C  THETA    Pattern angle (radians)
C  PHI      Pattern angle (radians)
C  BNE      Exponent in E plane
C  BNH      Exponent in H plane
C  POL      Polarization: 0 Linear, -1 RHC, +1 LHC
C  ETHETA   Theta component  V/m for 1 watt radiated power at 1 m.
C  EPHI     Phi component    V/m for 1 watt radiated power at 1 m.
C
      COMPLEX ETHETA,EPHI,ETHETE,EPHE
      DIMENSION ROT(3,3),VR(3),VT(3),VP(3),VTP(3),VPP(3),
     1 VRR(3),VTR(3),VPR(3)
C ------------ Find unit vectors for pattern direction
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
C ------------ Express VR in element coordinates for pattern
C              directions & Express VT and VP in element coordinates
      CALL PATROT(ROT,VR,VT,VP,THETE,PHE,VTP,VPP)
C ------------ Find pattern
      CALL COSPAT(NAP,THETE,PHE,BNE,BNH,POL,ETHETE,EPHE)
C ------------ Find unit vectors in element coordinate system
      CALL FFDIRC(THETE,PHE,VRR,VTR,VPR)
C ------------ Project element components onto re-expressed
C              unit vectors to find components
      ETHETA=ETHETE*DOT(VTR,VTP)+EPHE*DOT(VPR,VTP)
      EPHI=ETHETE*DOT(VTR,VPP)+EPHE*DOT(VPR,VPP)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RECCUR(W,H,NM,MM,SLANTY,SLANTX,AKZ,AKF,NY,NX,LUNIT)
C
C  Currents File of Rectangular Waveguide Horn in TE mode
C
C  W       Width of horn aperture along Y axis (m)
C  H       Height of horn aperture along X axis (m)
C  NM      Mode number along Y axis
C  MM      Mode number along X axis
C  SLANTY  Slant radius in Y axis plane
C  SLANTX  Slant radius in X axis plane
C  AKZ     Z-axis propagation constant in waveguide
C  AKF     Propagation constant in free space
C  NY      Number of points in Y axis (width) integrals
C  NX      Number of points in X axis (height) integrals
C  LUNIT   Logical unit of random access file for currents
C
      COMPLEX CURJ(3),CURM(3),QUADY,QUADX
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      DATA PI/3.141592654/,CC/.2997925/
      HX=H/NX
      HY=W/NY
      FREC(4)=HX*HY
      CURJ(3)=0.
      CURM(3)=0.
      FREC(3)=0.
      CONS=AKF*CC*400.*PI
      POWER=0.
      PK=AKF
      IBUF(1)=NX*NY
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=1
C ------- Loop along Y axis
      DO 1 I=1,NY
      FREC(2)=-W/2.+HY*(I-.5)
      Y=HY*(I-.5)
      SS=AKF*FREC(2)**2/SLANTY/2.
      QUADY=CMPLX(COS(SS),-SIN(SS))
C ------- Loop along X axis
      DO 1 J=1,NX
      FREC(1)=-H/2.+HX*(J-.5)
      X=HX*(J-.5)
      SS=AKF*FREC(1)**2/SLANTX/2.
      QUADX=CMPLX(COS(SS),-SIN(SS))*QUADY*FREC(4)
      CURJ(1)=-AKZ*SIN(NM*PI*Y/W)*COS(MM*PI*X/H)*NM*PI/W/CONS*QUADX
      CURJ(2)=-AKZ*MM*PI/H*COS(NM*PI*Y/W)*SIN(MM*PI*X/H)/CONS*QUADX
      CURM(1)=MM*PI/H*COS(NM*PI*Y/W)*SIN(MM*PI*X/H)*QUADX
      CURM(2)=-NM*PI/W*SIN(NM*PI*Y/W)*COS(MM*PI*X/H)*QUADX
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    1 POWER=POWER+(CABS(CURM(1)*CURJ(2))
     1 +CABS(CURM(2)*CURJ(1)))/FREC(4)
      CURN=SQRT(POWER)
      DO 3 I=2,KREC
      READ(LUNIT,REC=I)(FREC(NN),NN=1,19)
      DO 2 J=1,3
      CURJ(J)=CURJ(J)/CURN
    2 CURM(J)=CURM(J)/CURN
    3 WRITE(LUNIT,REC=I)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE REFCCU(XFD,PKC,ROT,NAP,BNE,BNH,POL,BLOCK,XB,LUNIT)
C
C  Reflector surface currents added to Geometry File
C
C  XFD(3)   Location of feed
C  PKC      Propagation constant
C
C  Rotated
C  Pattern approximation  I: E = cos(Theta/2)**N
C                        II: E = cos(Theta)**N
C
C  ROT(3,3) Rotation matrix
C  NAP      Pattern approximation number
C  BNE      Exponent in E plane
C  BNH      Exponent in H plane
C  POL      Polarization: 0 Linear, -1 RHC, +1 LHC
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C
      DIMENSION XFD(3),ROT(3,3),FREC(19),XB(1),XFR(3),SP(3),
     1 VR(3),VT(3),VP(3)
      COMPLEX CURJ(3),CURM(3),ETHETA,EPHI,PHA,HFIELD(3),UNIT(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 3 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for feed blockage
      IF(BLOCK(XB,XFD,FREC).NE.1)THEN
C  ------------- Find vector from feed to reflector point
      CALL VLINC(-1.,XFD,1.,FREC,XFR)
      CALL RETSP(XFR,SP)
      CALL FFDIRC(SP(2),SP(3),VR,VT,VP)
C  ------------- Find field
      CALL RCSPAT(ROT,NAP,SP(2),SP(3),BNE,BNH,POL,ETHETA,EPHI)
      PHASE=-SP(1)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))
      DO 1 J=1,3
      CURM(J)=0.
      UNIT(J)=FREC(J+4)*FREC(4)
    1 HFIELD(J)=2.*(VP(J)*ETHETA-VT(J)*EPHI)*PHA/SP(1)/ZZ
      CALL CCROSS(UNIT,HFIELD,CURJ)
      ELSE
C  ------------- Blocked
      DO 2 J=1,3
    2 CURJ(J)=0.
      ENDIF
    3 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE REFCUR(XFD,PKC,BLOCK,XB,LUNIT,IADD)
C
C  Reflector surface currents added to Geometry File
C  using Current Common
C
C  XFD(3)   Location of feed - Assumes currents centered on feed
C  PKC      Propagation constant
C  BLOCK    Blockage function
C  XB       Blockage function array
C  LUNIT    Logical unit of random access currents file
C  IADD     If 1, add currents to existing currents
C
C  The routine assumes that the currents in common have been rotated
C  to the proper orientation to point at the reflector; see FILROT
C
      DIMENSION XFD(3),FREC(19),XB(1)
      INTEGER*4 IBUF(19)
      COMPLEX CURJ(3),EFIELD(3),HFIELD(3),UNIT(3),CURM(3)
      EQUIVALENCE (FREC(8),CURJ(1)),(FREC(14),CURM(1)),(IBUF(3),PK)
      EXTERNAL BLOCK
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      IBUF(2)=1
      PK=PKC
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 3 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ----------- Find fields at the surface of the reflector
      CALL NFPATR(XFD,BLOCK,XB,FREC,EFIELD,HFIELD)
      DO 1 J=1,3
      CURM(J)=0.
C  ----------- 2*(Surface Normal)*(Patch Area)
    1 UNIT(J)=2.*FREC(J+4)*FREC(4)
      CALL CCROSS(UNIT,HFIELD,EFIELD)
      DO 2 J=1,3
      IF(IADD.NE.1)CURJ(J)=EFIELD(J)
      IF(IADD.EQ.1)CURJ(J)=CURJ(J)+EFIELD(J)
    2 CONTINUE
    3 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE REFICU(XFD,PKC,ROT,BLOCK,XB,LUNIT)
C
C  Reflector surface currents added to Geometry File
C
C  XFD(3)   Location of feed
C  PKC      Propagation constant
C
C  Rotated Interpolated Source
C
C  ROT(3,3) Rotation matrix
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C
      DIMENSION XFD(3),ROT(3,3),FREC(19),XB(1),XFR(3),SP(3),
     1 VR(3),VT(3),VP(3)
      COMPLEX CURJ(3),CURM(3),ETHETA,EPHI,PHA,HFIELD(3),UNIT(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 3 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for feed blockage
      IF(BLOCK(XB,XFD,FREC).NE.1)THEN
C  ------------- Find vector from feed to reflector point
      CALL VLINC(-1.,XFD,1.,FREC,XFR)
      CALL RETSP(XFR,SP)
      CALL FFDIRC(SP(2),SP(3),VR,VT,VP)
C  ------------- Find field
      INST=2
      CALL RINPAT(ROT,INST,SP(2),SP(3),ETHETA,EPHI)
      PHASE=-SP(1)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))
      DO 1 J=1,3
      UNIT(J)=FREC(J+4)*FREC(4)
      CURM(J)=0.
    1 HFIELD(J)=2.*(VP(J)*ETHETA-VT(J)*EPHI)*PHA/SP(1)/ZZ
      CALL CCROSS(UNIT,HFIELD,CURJ)
      ELSE
C  ------------- Blocked
      DO 2 J=1,3
      CURM(J)=0.
    2 CURJ(J)=0.
      ENDIF
    3 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE REFPCU(PKC,XINC,HFIELD,BLOCK,XB,LUNIT,INOUT)
C
C  Reflector surface currents added to Geometry File
C  Due to Plane Wave Incident
C
C  PKC      Propagation constant
C  XINC(3)  Unit vector in direction of plane wave
C  HFIELD   Incident magnetic field
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C  INOUT    +1 only use when normal towards plane wave
C           -1 only use when normal away from plane wave
C            0 either
C
      DIMENSION FREC(19),XB(1),XINC(3)
      COMPLEX CURJ(3),CURM(3),PHA,HFIELD(3),UNIT(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 4 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for blockage
      IF(BLOCK(XB,FREC,XINC).NE.1.AND.DOT(XINC,FREC(5))*INOUT.GE.0.)
     1 THEN
C  ------------- Find distance to reference plane
      PHASE=DOT(FREC,XINC)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))
      DO 2 J=1,3
      CURM(J)=0.
    2 UNIT(J)=2.*FREC(J+4)*FREC(4)*PHA
      CALL CCROSS(UNIT,HFIELD,CURJ)
      ELSE
C  ------------- Blocked
      DO 3 J=1,3
    3 CURJ(J)=0.
      ENDIF
    4 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE REHCUR(XFD,PKC,BLOCK,XB,LUNIT,IADD)
C
C  Reflector surface currents added to Geometry File
C  using Currents Common Source
C
C  XFD(3)   Location of feed (movement of currents)
C  PKC      Propagation constant
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C  IADD     If 1, add to existing currents
C
      DIMENSION XFD(3),FREC(19),XB(1)
      COMPLEX CURJ(3),EFIELD(3),HFIELD(3),UNIT(3),CUJJ(3),CUMM(3)
     1,CURM(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 3 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ----------- Find fields at the surface of the reflector
      CALL NFPATR(XFD,BLOCK,XB,FREC,EFIELD,HFIELD)
      DO 1 J=1,3
      UNIT(J)=FREC(J+4)*FREC(4)
    1 EFIELD(J)=-EFIELD(J)
      CALL CCROSS(UNIT,HFIELD,CUJJ)
      CALL CCROSS(EFIELD,UNIT,CUMM)
      DO 2 J=1,3
      IF(IADD.EQ.1)THEN
      CURJ(J)=CUJJ(J)+CURJ(J)
      CURM(J)=CUMM(J)+CURM(J)
      ELSE
      CURJ(J)=CUJJ(J)
      CURM(J)=CUMM(J)
      ENDIF
    2 CONTINUE
    3 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RETSP(X,S)
C 
C  Rectangular to Spherical Coordinates 
C  X - (X,Y,Z)
C  S - Radius, Theta (radians), Phi (radians) 
C 
      DIMENSION S(3),X(3) 
      PI=2.*ACOS(0.)
      S(1)=SQRT(X(1)*X(1)+X(2)*X(2)+X(3)*X(3))
      S(2)=0. 
      S(3)=0. 
      IF(S(1).LE.0.)RETURN
      S(2)=ACOS(X(3)/S(1))
      IF(S(2).EQ.0.OR.S(2).EQ.PI)RETURN 
      S(3)=ATAN2(X(2),X(1)) 
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RFSCCU(XFD,PKC,ROT,NAP,BNE,BNH,POL,BLOCK,XB,LUNIT,IADD)
C
C  Reflector surface currents added to Geometry File
C  using pattern approximation
C  Shadow only normal toward feed included
C
C  XFD(3)   Location of feed
C  PKC      Propagation constant
C
C  Rotated
C  Pattern approximation  I: E = cos(Theta/2)**N
C                        II: E = cos(Theta)**N
C
C  ROT(3,3) Rotation matrix
C  NAP      Pattern approximation number
C  BNE      Exponent in E plane
C  BNH      Exponent in H plane
C  POL      Polarization: 0 Linear, -1 RHC, +1 LHC
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C
      DIMENSION XFD(3),ROT(3,3),FREC(19),XB(1),XFR(3),SP(3),
     1 VR(3),VT(3),VP(3)
      COMPLEX CURJ(3),ETHETA,EPHI,PHA,HFIELD(3),UNIT(3),CUJJ(3),CURM(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK,SHADOW
      DATA ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 4 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for feed blockage
      IF(BLOCK(XB,XFD,FREC).NE.1.AND.SHADOW(FREC(5),XFD,FREC).NE.1)THEN
C  ------------- Find vector from feed to reflector point
      CALL VLINC(-1.,XFD,1.,FREC,XFR)
      CALL RETSP(XFR,SP)
      CALL FFDIRC(SP(2),SP(3),VR,VT,VP)
C  ------------- Find field
      CALL RCSPAT(ROT,NAP,SP(2),SP(3),BNE,BNH,POL,ETHETA,EPHI)
      PHASE=-SP(1)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))
      DO 1 J=1,3
      CURM(J)=0.
      UNIT(J)=FREC(J+4)*FREC(4)
    1 HFIELD(J)=2.*(VP(J)*ETHETA-VT(J)*EPHI)*PHA/SP(1)/ZZ
      CALL CCROSS(UNIT,HFIELD,CUJJ)
      ELSE
C  ------------- Blocked
      DO 2 J=1,3
      CURM(J)=0.
    2 CUJJ(J)=0.
      ENDIF
      DO 3 J=1,3
      IF(IADD.EQ.1)CURJ(J)=CURJ(J)+CUJJ(J)
      IF(IADD.NE.1)CURJ(J)=CUJJ(J)
    3 CONTINUE
    4 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RFSCUR(XFD,PKC,LUNIT,IADD)
C
C  Reflector surface currents added to Geometry File
C  using Current Common - Shadow only normal toward current included
C
C  XFD(3)   Location of feed - Assumes currents centered on feed
C  PKC      Propagation constant
C  LUNIT    Logical unit of random access currents file
C  IADD     If 1, add to existing currents
C
C  The routine assumes that the currents in common have been rotated
C  to the proper orientation to point at the reflector; see FILROT
C
      DIMENSION XFD(3),FREC(19),XB(4)
      INTEGER*4 IBUF(19)
      COMPLEX CURJ(3),EFIELD(3),HFIELD(3),UNIT(3),CURM(3)
      EQUIVALENCE (FREC(8),CURJ(1)),(IBUF(3),PK),(FREC(14),CURM(1))
      EXTERNAL SHADOW
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      IBUF(2)=1
      PK=PKC
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 4 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      DO 1 J=1,3
    1 XB(J)=FREC(J+4)
C  ----------- Find fields at the surface of the reflector
      CALL NFPATR(XFD,SHADOW,XB,FREC,EFIELD,HFIELD)
      DO 2 J=1,3
C  ----------- 2*(Surface Normal)*(Patch Area)
    2 UNIT(J)=2.*FREC(J+4)*FREC(4)
      CALL CCROSS(UNIT,HFIELD,EFIELD)
      DO 3 J=1,3
      CURM(J)=0.
      IF(IADD.NE.1)CURJ(J)=EFIELD(J)
      IF(IADD.EQ.1)CURJ(J)=CURJ(J)+EFIELD(J)
    3 CONTINUE
    4 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RFSICU(XFD,PKC,ROT,BLOCK,XB,LUNIT,IADD)
C
C  Reflector surface currents added to Geometry File
C  Shadow only normal toward feed included
C
C  XFD(3)   Location of feed
C  PKC      Propagation constant
C
C  Rotated Interpolated Source
C
C  ROT(3,3) Rotation matrix
C  BLOCK    Blockage function (external) = 1 when blocked
C  XB       Array of variables for blockage function
C  LUNIT    Logical unit of random access currents file
C
      DIMENSION XFD(3),ROT(3,3),FREC(19),XB(1),XFR(3),SP(3),
     1 VR(3),VT(3),VP(3)
      COMPLEX CURJ(3),ETHETA,EPHI,PHA,HFIELD(3),UNIT(3),CUJJ(3),CURM(3)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK,SHADOW
      DATA ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C  ------------- Loop over current patches
      DO 4 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C  ------------- Check for feed blockage
      IF(BLOCK(XB,XFD,FREC).NE.1.AND.SHADOW(FREC(5),XFD,FREC).NE.1)THEN
C  ------------- Find vector from feed to reflector point
      CALL VLINC(-1.,XFD,1.,FREC,XFR)
      CALL RETSP(XFR,SP)
      CALL FFDIRC(SP(2),SP(3),VR,VT,VP)
C  ------------- Find field
      INST=2
      CALL RINPAT(ROT,INST,SP(2),SP(3),ETHETA,EPHI)
      PHASE=-SP(1)*PKC
      PHA=CMPLX(COS(PHASE),SIN(PHASE))
      DO 1 J=1,3
      UNIT(J)=FREC(J+4)*FREC(4)
      CURM(J)=0.
    1 HFIELD(J)=2.*(VP(J)*ETHETA-VT(J)*EPHI)*PHA/SP(1)/ZZ
      CALL CCROSS(UNIT,HFIELD,CUJJ)
      ELSE
C  ------------- Blocked
      DO 2 J=1,3
      CURM(J)=0.
    2 CURJ(J)=0.
      ENDIF
      DO 3 J=1,3
      IF(IADD.EQ.1)CURJ(J)=CURJ(J)+CUJJ(J)
      IF(IADD.NE.1)CURJ(J)=CUJJ(J)
    3 CONTINUE
    4 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RIFPAT(LUNIT,ROT,INST,THETA,PHI,ETHETA,EPHI)
C
C  Rotated
C  Interpolated Measured Pattern
C
C  ROT(3,3) Rotation matrix
C  INST   - 1 Initialize: Read from file of ASCII listing of data
C           2 Return pattern value
C  THETA    Pattern angle (radians) (Value to add to bias to gain
C              on initialization dB)
C  PHI      Pattern angle (radians) (Value to add to bias to gain
C              on initialization dB)
C  ETHETA   Theta component  V/m for 1 watt radiated power at 1 m.
C  EPHI     Phi component    V/m for 1 watt radiated power at 1 m.
C
      COMPLEX ETHETA,EPHI,ETHETE,EPHE
      DIMENSION ROT(3,3),VR(3),VT(3),VP(3),VTP(3),VPP(3),
     1 VRR(3),VTR(3),VPR(3)
      DATA TR/.01745329/
      IF(INST.EQ.1)THEN
      CALL PATINF(LUNIT,INST,THETA,PHI,ETHETE,EPHE)
      ELSE
C ------------ Find unit vectors for pattern direction
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
C ------------ Express VR in element coordinates for pattern
C              directions & Express VT and VP in element coordinates
      CALL PATROT(ROT,VR,VT,VP,THETE,PHE,VTP,VPP)
C ------------ Find pattern
      TH=THETE/TR
      PH=PHE/TR
      IF(PH.LT.0.)PH=PH+360.
      CALL PATINF(LUNIT,INST,TH,PH,ETHETE,EPHE)
C ------------ Find unit vectors in element coordinate system
      CALL FFDIRC(THETE,PHE,VRR,VTR,VPR)
C ------------ Project element components onto re-expressed
C              unit vectors to find components
      ETHETA=ETHETE*DOT(VTR,VTP)+EPHE*DOT(VPR,VTP)
      EPHI=ETHETE*DOT(VTR,VPP)+EPHE*DOT(VPR,VPP)
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RINGEO(AXIS,DIN,DOUT,VP,ALINC,LUNIT,ICAT)
C
C  Geometry file of Ring Disk rotated and located in space
C  Polar Grid
C
C  AXIS(3) Axis in direction of normal
C  DIN     Inner Diameter of disk
C  DOUT    Outer Diameter of disk
C  VP(3)   Location of center
C  ALINC   Length increment in aperture plane for current patches
C  LUNIT   Logical unit of random access file for currents
C  ICAT    If 1, concatenate
C
      DIMENSION VP(1),FREC(19),PP(3),AXIS(3),SP(3),ROT(3,3),EU(3),
     1 IA(3),VEC(3)
      INTEGER*4 IBUF(19)
      DATA PI/3.14159654/,IA/3,2,3/
      CALL RETSP(AXIS,SP)
C  ------------- Find rotation matrix
      EU(1)=SP(3)
      EU(2)=SP(2)
      EU(3)=0.
      CALL EULER(EU,IA,ROT)
      NR=(DOUT-DIN)/ALINC/2.+.5
      HR=(DOUT-DIN)/2./NR
C  ------------- Find normal
      VEC(1)=0.
      VEC(2)=0.
      VEC(3)=1.
      CALL MTMULT(VEC,ROT,FREC(5),1,3,3)
      IF(ICAT.EQ.1)THEN
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=IBUF(1)+1
      ELSE
      KREC=1
      ENDIF
C  ------------- Loop over radius
      DO 2 J=1,NR
      RAD=(FLOAT(J-1)+.5)*HR+DIN/2.
C  ------------- Find differential area on aperture plane
      R1=RAD-HR/2.
      R2=RAD+HR/2.
      NP=2.*PI*RAD/ALINC+.5
      NP=NP/4
      NP=(NP+1)*4
      HP=2.*PI/NP
C  ------------- Area of wedge
      FREC(4)=(R2**2-R1**2)*HP/2.
C  ------------- Loop over Phi
      DO 1 I=1,NP
      PH=FLOAT(I-1)*HP
      PP(1)=RAD*COS(PH)
      PP(2)=RAD*SIN(PH)
      PP(3)=0.
      CALL MTMULT(PP,ROT,VEC,1,3,3)
C  ------------- Move to center of plate
      CALL VLINC(1.,VP,1.,VEC,FREC)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RINPAT(ROT,INST,THETA,PHI,ETHETA,EPHI)
C
C  Rotated
C  Interpolated Measured Pattern
C
C  ROT(3,3) Rotation matrix
C  INST   - 1 Initialize: Read from file of ASCII listing of data
C           2 Return pattern value
C  THETA    Pattern angle (radians) (Value to add to bias to gain
C              on initialization dB)
C  PHI      Pattern angle (radians) (Value to add to bias to gain
C              on initialization dB)
C  ETHETA   Theta component  V/m for 1 watt radiated power at 1 m.
C  EPHI     Phi component    V/m for 1 watt radiated power at 1 m.
C
      COMPLEX ETHETA,EPHI,ETHETE,EPHE
      DIMENSION ROT(3,3),VR(3),VT(3),VP(3),VTP(3),VPP(3),
     1 VRR(3),VTR(3),VPR(3)
      DATA TR/.01745329/
      IF(INST.EQ.1)THEN
      CALL PATIND(INST,THETA,PHI,ETHETA,EPHI)
      ELSE
C ------------ Find unit vectors for pattern direction
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
C ------------ Express VR in element coordinates for pattern
C              directions & Express VT and VP in element coordinates
      CALL PATROT(ROT,VR,VT,VP,THETE,PHE,VTP,VPP)
C ------------ Find pattern
      TH=THETE/TR
      PH=PHE/TR
      CALL PATIND(INST,TH,PH,ETHETE,EPHE)
C ------------ Find unit vectors in element coordinate system
      CALL FFDIRC(THETE,PHE,VRR,VTR,VPR)
C ------------ Project element components onto re-expressed
C              unit vectors to find components
      ETHETA=ETHETE*DOT(VTR,VTP)+EPHE*DOT(VPR,VTP)
      EPHI=ETHETE*DOT(VTR,VPP)+EPHE*DOT(VPR,VPP)
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RMCCUR(W,H,NM,MM,SLANTY,SLANTX,AKZ,AKF,NY,NX,LUNIT)
C
C  Currents File of Rectangular Waveguide Horn in TM mode
C
C  W       Width of horn aperture along Y axis (m)
C  H       Height of horn aperture along X axis (m)
C  NM      Mode number along Y axis
C  MM      Mode number along X axis
C  SLANTY  Slant radius in Y axis plane
C  SLANTX  Slant radius in X axis plane
C  AKZ     Z-axis propagation constant in waveguide
C  AKF     Propagation constant in free space
C  NY      Number of points in Y axis (width) integrals
C  NX      Number of points in X axis (height) integrals
C  LUNIT   Logical unit of random access file for currents
C
      COMPLEX CURJ(3),CURM(3),QUADY,QUADX
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      DATA PI/3.141592654/,CC/.2997925/,EPS/8.854185E-3/
      HX=H/NX
      HY=W/NY
      FREC(4)=HX*HY
      CURJ(3)=0.
      CURM(3)=0.
      FREC(3)=0.
      CONS=AKF*CC*EPS
      POWER=0.
      PK=AKF
      IBUF(1)=NX*NY
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=1
C ------- Loop along Y axis
      DO 1 I=1,NY
      FREC(2)=-W/2.+HY*(I-.5)
      Y=HY*(I-.5)
      SS=AKF*FREC(2)**2/SLANTY/2.
      QUADY=CMPLX(COS(SS),-SIN(SS))
C ------- Loop along X axis
      DO 1 J=1,NX
      FREC(1)=-H/2.+HX*(J-.5)
      X=HX*(J-.5)
      SS=AKF*FREC(1)**2/SLANTX/2.
      QUADX=CMPLX(COS(SS),-SIN(SS))*QUADX*FREQ(4)
      CURJ(1)=SIN(NM*PI*Y/W)*COS(MM*PI*X/H)*MM*PI/H*QUADX
      CURJ(2)=NM*PI/W*COS(NM*PI*Y/W)*SIN(MM*PI*X/H)*QUADX
      CURM(1)=-AKZ*NM*PI/W*COS(NM*PI*Y/W)*SIN(MM*PI*X/H)*QUADX/CONS
      CURM(2)=-AKZ*MM*PI/H*SIN(NM*PI*Y/W)*COS(MM*PI*X/H)*QUADX/CONS
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    1 POWER=POWER+(CABS(CURM(1)*CURJ(2))+CABS(CURM(2)*CURJ(1)))/FREQ(4)
      CURN=SQRT(POWER)
      DO 3 I=2,KREC
      READ(LUNIT,REC=I)(FREC(NN),NN=1,19)
      DO 2 J=1,3
      CURJ(J)=CURJ(J)/CURN
    2 CURM(J)=CURM(J)/CURN
    3 WRITE(LUNIT,REC=I)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RPPERM(P,RL,W,POS,AM,IEDGE,POL)
C
C  Perimeter function of rectangular patch
C
C  P   Perimeter value
C  RL  Resonant length along X axis
C  W   Non-resonant width
C  POS    Position on patch centered on origin
C  AM(3)  Normalized magnetic current direction
C  IEDGE  Edge number: Intersects axis: 1 +X, 2 +Y, 3 -X, 4 -Y
C  POL    Polarization: 0 Linear, -1 RHC, +1 LHC
C
      DIMENSION POS(3)
      COMPLEX AM(3)
      DATA PI/3.141592654/,S2/1.4142135/
      POS(3)=0.
      AM(3)=0.
      IF(IEDGE.EQ.1)THEN
      POS(1)=RL/2.
      POS(2)=-W/2.+P
      AM(1)=0.
      AM(2)=1.
      IF(POL.NE.0.)AM(2)=(AM(2)-CMPLX(0.,POL)*SIN(POS(2)*PI/2.))/S2
      ELSE IF(IEDGE.EQ.2)THEN
      POS(1)=-RL/2.+P
      POS(2)=W/2.
      AM(1)=-SIN(POS(1)*PI/2.)
      AM(2)=0.
      IF(POL.NE.0.)AM(1)=(AM(1)-CMPLX(0.,POL))/S2
      ELSE IF(IEDGE.EQ.3)THEN
      POS(1)=-RL/2.
      POS(2)=-W/2.+P
      AM(1)=0.
      AM(2)=1.
      IF(POL.NE.0.)AM(2)=(AM(2)+CMPLX(0.,POL)*SIN(POS(2)*PI/2.))/S2
      ELSE IF(IEDGE.EQ.4)THEN
      POS(1)=-RL/2.+P
      POS(2)=-W/2.
      AM(1)=SIN(POS(1)*PI/2.)
      AM(2)=0.
      IF(POL.NE.0.)AM(1)=(AM(1)-CMPLX(0.,POL))/S2
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION RRADCN(W)
C
C  Radiation conductance for square patch: W width in wavelengths
C
      DIMENSION WID(22),ZR(22)
      DATA WID/.1,.12,.14,.16,.18,.2,.22,.24,.26,.28,.3,.32,.34,.36,
     1 .38,.4,.42,.44,.46,.48,.5,.52/
      DATA ZR/111.6,93.759,81.13,71.755,64.546,58.848,54.246,50.458,
     1 47.292,44.606,42.296,40.283,38.504,36.911,35.464,34.131,
     2 32.885,31.707,30.579,29.49,28.431,27.398/
      ZZ=ALINP(W,WID,ZR,22,3)
      RRADCN=1./(ZZ/2.)**2
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE RRMAT(XF,XS,RR,R)
C
C  Matrix RR between field point: XF(3) and source point: XS(3)
C  Outputs: RR  Matrix, R distance between points
C
      DIMENSION XF(3),XS(3),RR(3,3),DD(3)
      R=0.
      DO1I=1,3
      DD(I)=XF(I)-XS(I)
    1 R=R+DD(I)**2
      DO2I=1,3
      DO2J=1,3
    2 RR(I,J)=DD(I)*DD(J)/R
      R=SQRT(R)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE SCACOM(POWER,PHASE)
C
C  Scales currents in common
C
C  POWER  Power (watts) of currents in common
C  PHASE  Phase (degrees)
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
      COMPLEX CURJA,CURMA,CV
      DATA TR/.01745329/
      CV=SQRT(POWER)*CMPLX(COS(PHASE*TR),SIN(PHASE*TR))
      DO 2 I=1,NCUR
      DO 1 J=1,3
      CURJA(J,I)=CURJ(J)*CV
    1 CURMA(J,I)=CURM(J)*CV
    2 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      COMPLEX FUNCTION SCUTAL(RL1,RL2,F,X,Y,NINT,POL)
C
C  Mutual admittance between two square patch antennas
C  Using currents in common for first patch
C
C  RL1     Resonant length of 1st patch (cm)
C  RL2     Resonant length of 2nd patch (cm)
C  F       Frequency (GHz)
C  X,Y     Position of 2nd patch (cm)
C  NINT    Points in integral along edges
C  POL     Polarization: 0 Linear, -1 RHC, +1 LHC
C
C  Note:   Feeds located on X axis
C
      COMPLEX CCDOT,EFIELD(3),HFIELD(3),AM(3),SS
      DIMENSION XF(3),XC(3),XB(1)
      EXTERNAL BLOCKN
      DATA CC/.2997925/,XC/0.,0.,0./
      WID1=RL1*.01
      WID2=RL2*.01
      WAVEL=CC/F
      HP=WID2/NINT
      V1=SQRT(1./RRADCN(WID1/WAVEL))
C ------------------- Loop on edges of second patch
      SS=0.
      DO 1 IEDGE=1,4
C ------------------- Find reaction along edge
      DO 1 I=1,NINT
      POS=HP*(I-.5)
      CALL RPPERM(POS,WID2,WID2,XF,AM,IEDGE,POL)
      XF(1)=XF(1)+X*.01
      XF(2)=XF(2)+Y*.01
C ------------------- Find fields at point due to 1st patch
      CALL NFPATR(XC,BLOCKN,XB,XF,EFIELD,HFIELD)
C ------------------- Find reaction at point
    1 SS=CCDOT(HFIELD,AM)*HP+SS
C ------------------- Half space radiation, reduce by 1/2
      SCUTAL=-SS/V1/2.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION SHADOW(ANORM,XS,XF)
C
C  Shadow: Field only if reflector normal toward the current
C
C  ANORM(3)   Normal to surface
C  XS(3)      Source point (current)
C  XF(3)      Field point (reflector surface)
C
      DIMENSION ANORM(1),XS(1),XF(1),XTT(3)
      CALL VLINC(1.,XF,-1.,XS,XTT)
      SHADOW=0.
      IF(DOT(ANORM,XTT).GT.0.)SHADOW=1.
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE SPACUR(WIDTH,FREQ,POL,NPTS,LUNIT)
C
C  Current file of square microstrip patch
C
C  WIDTH     Effective width of patch (m)
C  FREQ      Frequency (GHz)
C  POL       Polarization: 0 linear, -1 RHC, +1 LHC
C  NPTS      Number of points in integrals along each edge
C  LUNIT     Logical unit of random access file with currents
C
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      COMPLEX CURM(3),AM(3)
      EQUIVALENCE (IBUF(3),PK),(FREC(14),CURM(1))
      DATA CC/.2997925/,PI/3.141592654/
      WAVEL=CC/FREQ
      PK=2.*PI/WAVEL
      W=WIDTH/WAVEL
C --------------- Find maximum magnetic current for 1 w. input
      AMM=2.*SQRT(1./RRADCN(W))
      HP=WIDTH/NPTS
      IBUF(1)=4*NPTS
      IBUF(2)=2
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=1
C --------------- Loop on edges; axis: X, Y, -X, -Y
      DO 3 J=1,4
      DO 2 I=1,NPTS
      POS=HP*(I-.5)
      CALL RPPERM(POS,WIDTH,WIDTH,FREC,AM,J,POL)
      KREC=KREC+1
      DO 1 K=1,3
    1 CURM(K)=AM(K)*AMM*HP
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
    3 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE SPCCUR(PKC,LUNIT)
C
C  Adds Currents on Sphere using SPHGEO geometry file
C
C  PKC     Propagation constant
C  LUNIT   Logical unit of random access file for currents
C
      COMPLEX CURJ(3),CURM(3),EFIELD(3),HFIELD(3),UNIT(3),ETHETA,
     1 EPHI,EPHS
      DIMENSION FREC(19),VR(3),VT(3),VP(3)
      INTEGER*4 IBUF(19)
      COMMON /PATR/BNE,BNH,NAPPR,POL
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      DATA TR/.01745329/,ZZ/376.73/
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 2 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------------- Convert position to spherical coordinates
      RADIUS=SQRT(DOT(FREC,FREC))
      PHAS=RADIUS*PK
      EPHS=CMPLX(COS(PHAS),-SIN(PHAS))/RADIUS
      THETA=ACOS(FREC(3)/RADIUS)
      IF(ABS(FREC(1)).GT.1.E-5)THEN
      PHI=ATAN2(FREC(2),FREC(1))
      ELSE
      PHI=SIGN(90.,FREC(2))*TR
      ENDIF
      CALL FFDIRC(THETA,PHI,VR,VT,VP)
      CALL COSPAT(NAPPR,THETA,PHI,BNE,BNH,POL,ETHETA,EPHI)
      DO 3 L=1,3
    3 UNIT(L)=VR(L)
      DO 4 L=1,3
    4 EFIELD(L)=(ETHETA*VT(L)+EPHI*VP(L))*EPHS
      CALL CCROSS(EFIELD,UNIT,HFIELD)
      DO 1 J=1,3
      HFIELD(J)=HFIELD(J)/ZZ
    1 UNIT(J)=FREC(J+4)*FREC(4)
      CALL CCROSS(UNIT,HFIELD,CURJ)
      CALL CCROSS(EFIELD,UNIT,CURM)
    2 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      FUNCTION SPGAIN(W)
C
C  Square Patch Gain dB: W width in wavelengths
C
      DIMENSION WID(22),ZR(22)
      DATA WID/.1,.12,.14,.16,.18,.2,.22,.24,.26,.28,.3,.32,.34,.36,
     1 .38,.4,.42,.44,.46,.48,.5,.52/
      DATA ZR/111.6,93.759,81.13,71.755,64.546,58.848,54.246,50.458,
     1 47.292,44.606,42.296,40.283,38.504,36.911,35.464,34.131,
     2 32.885,31.707,30.579,29.49,28.431,27.398/
      DATA PI/3.14159265/,ZZO/376.73/
      ZZ=ALINP(W,WID,ZR,22,3)
      GAIN=4.*PI/ZZO*(ZZ*W)**2
      SPGAIN=10.*ALOG10(GAIN)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE SPHCUR(PKC,BLOCK,XB,LUNIT)
C
C  Adds Currents on Sphere using SPHGEO geometry file
C
C  PKC     Propagation constant
C  LUNIT   Logical unit of random access file for currents
C
      COMPLEX CURJ(3),CURM(3),EFIELD(3),HFIELD(3),UNIT(3)
      DIMENSION FREC(19),XC(3),XB(1)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      EXTERNAL BLOCK
      DATA XC/0.,0.,0./
      READ(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      PK=PKC
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      DO 2 I=1,IBUF(1)
      READ(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
      CALL NFPATR(XC,BLOCK,XB,FREC,EFIELD,HFIELD)
      DO 1 J=1,3
    1 UNIT(J)=FREC(J+4)*FREC(4)
      CALL CCROSS(UNIT,HFIELD,CURJ)
      CALL CCROSS(EFIELD,UNIT,CURM)
    2 WRITE(LUNIT,REC=I+1)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE SPHGEO(RADIUS,ALINC,LUNIT,NEMI)
C
C  Geometry portion of sphere in currents file
C
C  RADIUS  Radius of sphere (m)
C  ALINC   Length increment of patches
C  LUNIT   Logical unit of random access file for currents
C  NEMI    1 Upper hemisphere only, 2 Sphere
C
      DIMENSION FREC(19),SP(3)
      INTEGER*4 IBUF(19)
      DATA PI/3.141592654/
      SP(1)=1.
      NT=RADIUS*PI/ALINC/2.+.1
      DELT=PI/NT/2.
      L=1
C ------------ Loop on hemisphere
      DO 3 N=1,NEMI
      SCON=(N-1)*PI/2.
C ------------ Loop on Theta
      DO 2 I=1,NT
      SP(2)=DELT*(I-.5)+SCON
      DL=ABS(COS(SP(2)-.5*DELT)-COS(SP(2)+.5*DELT))*RADIUS
C ------------ Loop on Phi
      NP=2.*PI*SIN(SP(2))*RADIUS/ALINC+1.
      DELP=2.*PI/NP
      DO 2 J=1,NP
      SP(3)=DELP*(J-1)
C ------------ Differential area
      FREC(4)=DL*DELP*RADIUS
C ------------ Unit normal
      CALL ARADS(SP,FREC(5))
      DO 1 K=1,3
    1 FREC(K)=RADIUS*FREC(K+4)
      L=L+1
    2 WRITE(LUNIT,REC=L)(FREC(NN),NN=1,19)
    3 CONTINUE
      IBUF(1)=L-1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE SUBBGE(XMIN,XMAX,YMIN,YMAX,A,B,TYPE,BLOCK,XB,
     1 VP,NX,NY,LUNIT)
C
C  Subreflector Geometry for Currents File
C  using rectangular grid and external blockage function for rim
C
C  XMIN    Minimum X axis position of rim
C  XMAX    Maximum X axis position of rim
C  YMIN    Minimum Y axis position of rim
C  YMAX    Maximum Y axis position of rim
C  A       Denominator factor of Z
C  B       Denominator factor of X & Y
C  TYPE    1) Hyperboloid (Cassegrain)  2) Ellipsoid (Gregorian)
C  BLOCK   External blockage function to determine rim shape
C  XB( )   Blockage function variables
C  VP(3)   Location of hyperboloid (ellipsoid) center
C
C  Note:   Hyperboloid (ellipsoid) axis along Z-axis
C          and located on positive Z-axis
C  LUNIT   Logical unit of random access file for currents
C
      DIMENSION VP(1),FREC(19),PP(3),XB(1),VR(3)
      INTEGER*4 IBUF(19)
      EXTERNAL BLOCK
      DATA VR/0.,0.,1./
      KREC=1
      HX=(XMAX-XMIN)/NX
      HY=(YMAX-YMIN)/NY
      KREC=1
C  ------------- Loop over X-axis
      DO 2 J=1,NX
      PP(1)=XMIN+HX*(J-.5)
      DO 1 I=1,NY
      PP(2)=YMIN+HY*(I-.5)
      PP(3)=-1.
      IF(BLOCK(XB,PP,VR).EQ.1.)THEN
C  ------------- Point within rim
      RP=SQRT(PP(1)**2+PP(2)**2)
      PP(3)=A*SQRT(1.-(RP/B)**2*(-1.)**TYPE)
C  ------------- Find unit normal
      IF(TYPE.EQ.1)CALL HYPNM(PP,A,B,FREC(5))
      IF(TYPE.EQ.2)CALL ELLNM(PP,A,B,FREC(5))
C  ------------- Adjust area
      FREC(4)=HX*HY/ABS(FREC(7))
      CALL VLINC(1.,VP,1.,PP,FREC)
      KREC=KREC+1
      WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
      ENDIF
    1 CONTINUE
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      RETURN
      END



      SUBROUTINE SUBGEO(DIA,A,B,OFFSET,TYPE,VP,ALINC,LUNIT)
C
C  Offset Subreflector Geometry for Currents File
C  Polar Grid
C
C  DIA     Diameter of projected reflector
C  A       Denominator factor of Z
C  B       Denominator factor of X & Y
C  OFFSET  Offset (center of circular aperture in X-Y plane)
C  TYPE    1) Hyperboloid (Cassegrain)  2) Ellipsoid (Gregorian)
C  VP(3)   Location of hyperboloid (ellipsoid) center
C
C  Note:   Hyperboloid (ellipsoid) axis along Z-axis
C          and located on positive Z-axis
C  ALINC   Current patch increment
C  LUNIT   Logical unit of random access file for currents
C
      DIMENSION VP(1),FREC(19),PP(3),OFFSET(2)
      INTEGER*4 IBUF(19)
      DATA PI/3.14159654/
      NR=DIA/ALINC/2.+.5
      HR=DIA/2./NR
      KREC=1
C  ------------- Loop over radius
      DO 2 J=1,NR
      RAD=(FLOAT(J-1)+.5)*HR
C  ------------- Find differential area on aperture plane
      R1=RAD-HR/2.
      R2=RAD+HR/2.
      AREA=(R2**2-R1**2)/2.
      NP=2.*PI*RAD/ALINC+.5
      NP=NP/4
      NP=(NP+1)*4
      HP=2.*PI/NP
C  ------------- Loop over Phi
      DO 1 I=1,NP
      PH=FLOAT(I-1)*HP
      PP(1)=OFFSET(1)+RAD*COS(PH)
      PP(2)=OFFSET(2)+RAD*SIN(PH)
      RP=SQRT(PP(1)**2+PP(2)**2)
      PP(3)=A*SQRT(1.-(RP/B)**2*(-1.)**TYPE)
C  ------------- Find unit normal
      IF(TYPE.EQ.1)CALL HYPNM(PP,A,B,FREC(5))
      IF(TYPE.EQ.2)CALL ELLNM(PP,A,B,FREC(5))
C  ------------- Adjust area
      FREC(4)=AREA*HP/ABS(FREC(7))
      CALL VLINC(1.,VP,1.,PP,FREC)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      RETURN
      END
      SUBROUTINE HYPNM(PO,A,B,AN)
C 
C  Normal of Hyperboloid
C 
C  Hyperboloid coordinates for centered figure
C  PO  Position on Hyperboloid
C  A   Denominator factor of Z
C  B   Denominator factor of X & Y
C  AN  Normalized Normal Vector 
C 
C  The Hyperboloid is axisymmetric about Z axis 
C 
      DIMENSION PO(3),AN(3) 
      DEN=SQRT(PO(1)*PO(1)+PO(2)*PO(2)+(PO(3)*B*B/(A*A))**2)
      AN(1)=PO(1)/DEN
      AN(2)=PO(2)/DEN
      AN(3)=-PO(3)*(B/A)**2/DEN
      RETURN
      END 
      SUBROUTINE ELLNM(PO,A,B,AN)
C 
C  Inward Normal of Ellipsoid 
C 
C  Ellipsoid coordinates for centered figure
C  PO  Position on Ellipsoid
C  A   Denominator factor of Z
C  B   Denominator factor of X & Y
C  AN  Normalized Normal Vector 
C 
C  The Ellipsoid is axisymmetric about Z axis 
C 
      DIMENSION PO(3),AN(3) 
      DEN=SQRT(PO(1)*PO(1)+PO(2)*PO(2)+(PO(3)*B*B/(A*A))**2)
      AN(1)=-PO(1)/DEN
      AN(2)=-PO(2)/DEN
      AN(3)=-PO(3)*(B/A)**2/DEN
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE VCROSS(A,B,C)
C 
C  Vector Cross Product A X B = C where A is real and B is complex
C 
C  Vectors are Expressed in Rectangular Coordinates 
C 
      DIMENSION A(1)
      COMPLEX B(1),C(1)
      C(1)=A(2)*B(3)-A(3)*B(2)
      C(2)=A(3)*B(1)-A(1)*B(3)
      C(3)=A(1)*B(2)-A(2)*B(1)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 



      SUBROUTINE VDICMG(FREQ,FD,AL,POLR,UU,UL,NPTS,CURR,IMAGE,LUNIT,ZIN)
C
C  Current multiplier for Vee dipole and Input Impedance
C
C  FREQ    Frequency (GHz)
C  FD(3)   Feed point (m) (height = FD(3))
C  AL      Length of dipole (sum of both arms) (m)
C  POLR    Radius of rod of dipole
C  UU(3)   Direction of unit vector of upper arm
C  UL(3)   Direction of unit vector of lower arm
C  NPTS    Number of points along each arm
C  CURR    Multiplier on current magnitude (for mutual = 1)
C  IMAGE   0 - dipole alone, 1 - dipole over ground plane
C  LUNIT   Logical unit of file for currents
C
      COMPLEX ZIN,Z12
      DIMENSION FD(3),UU(3),UL(3),UUI(3),ULI(3),FDI(3)
      DATA CC/.2997925/,PI/3.14159265/
C ------------- Find currents on single dipole
      IMAGG=0
      CURR=1.
      CALL VDICUR(FREQ,FD,AL,UU,UL,NPTS,CURR,IMAGG,LUNIT)
C ------------- Load into currents common
      CALL CURCOM(LUNIT)
      FDI(1)=FD(1)
      FDI(2)=FD(2)+POLR
      FDI(3)=FD(3)
C ------------- Find self impedance
      CALL VDIMUC(FDI,AL,ALC,UU,UL,NPTS,ZIN)
      IF(IMAGE.EQ.1)THEN
      DO 1 I=1,2
      FDI(I)=FD(I)
      UUI(I)=UU(I)
    1 ULI(I)=UL(I)
      FDI(3)=-FD(3)
      UUI(3)=-UU(3)
      ULI(3)=-UL(3)
C -------------  Find mutual impedance with image
      CALL VDIMUC(FDI,AL,ALC,UUI,ULI,NPTS,Z12)
      ZIN=ZIN-Z12
      ENDIF
      CURR=1./SQRT(REAL(ZIN)*SIN(PI*AL*FREQ/CC))
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
C
C  Note fewer currents are needed for pattern calculations than for the
C  self impedance.  The currents file can be reinitialized VDICUR with
C  fewer points but with CURR from this routine to normalize power to
C  1 watt.
C
      END



      SUBROUTINE VDICUR(FREQ,FD,AL,UU,UL,NPTT,CURR,IMAGE,LUNIT)
C
C  Currents file for Vee Dipole (built in Simpson's rule integration)
C
C  FREQ    Frequency (GHz)
C  FD(3)   Feed point (m)
C  AL      Length of dipole (sum of both arms) (m)
C  UU(3)   Direction of unit vector of upper arm
C  UL(3)   Direction of unit vector of lower arm
C  NPTT    Number of points along each arm
C  CURR    Multiplier on current magnitude (for mutual = 1)
C  IMAGE   0 - dipole, 1 - add currents of image in Z = 0 plane
C  LUNIT   Logical unit of file for currents
C
      DIMENSION FREC(19),FD(3),UU(3),UL(3),U(3)
      INTEGER*4 IBUF(19)
      COMPLEX CURJ(3)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1))
      DATA CC/.2997925/,PI/3.141592654/
      WAVEL=CC/FREQ
      PK=2.*PI/WAVEL
C --------- Round points up to odd for Simpson's rule
      NPTS=NPTT
      IF(MOD(NPTS,2).EQ.0)NPTS=NPTS+1
      IF(IMAGE.EQ.0)THEN
      IBUF(1)=2*NPTS
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=1
      ELSE
      IBUF(1)=4*NPTS
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=2*NPTS+1
      ENDIF
      AI=AL/(2.*(NPTS-1))
      CURC=CURR/3.
C ---------- Loop on arms
      DO 4 K=1,2
      DO 1 I=1,3
      IF(K.EQ.1)U(I)=UU(I)
      IF(K.EQ.2)U(I)=UL(I)
    1 CONTINUE
C ---------- Loop on points along dipole
      DO 3 I=1,NPTS
      T=(I-1)*AI
      CALL VLINC(1.,FD,T,U,FREC)
      CUR=-SIN(PK*(AL/2.-T))*CURC*AI*(-1.)**K
C ---------- Simpson's rule weights
      IF(I.GT.1.AND.I.LT.NPTS)THEN
      IF(MOD(I-1,2).EQ.1)CUR=CUR*4.
      IF(MOD(I-1,2).EQ.0)CUR=CUR*2.
      ENDIF
      IF(IMAGE.EQ.0)THEN
C ---------- Normal currents including Simpson's weights
      DO 2 J=1,3
    2 CURJ(J)=U(J)*CUR
      ELSE
C ---------- Image currents
      FREC(3)=-FREC(3)
      CURJ(1)=-U(1)*CUR
      CURJ(2)=-U(2)*CUR
      CURJ(3)=U(3)*CUR
      ENDIF
      KREC=KREC+1
    3 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    4 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VDIMUC(FD,AL,ALC,UU,UL,NPTT,Z12)
C
C  Mutual coupling between Vee Dipole and Currents File with dipole
C  (built in Simpson's rule integration)
C
C  FD(3)    Location of Vee Dipole
C  AL       Length of dipole (sum of arms) (m)
C  ALC      Length of dipole coupling to
C  UU(3)    Unit vector in direction of upper arm
C  UL(3)    Unit vector in direction of lower arm
C  NPTT	    Number of points
C  Z12      Mutual impedance
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMPLEX SS,EFIELD(3),HFIELD(3),Z12,CURC(3),CCDOT
      DIMENSION FD(3),XC(3),XS(3),UU(3),UL(3),U(3),XB(1)
      EXTERNAL BLOCKN
      DATA XC/0.,0.,0./
      SS=0.
C --------- Round points up to odd for Simpson's rule
      NPTS=NPTT
      IF(MOD(NPTS,2).EQ.0)NPTS=NPTS+1
      ARI=AL/(2.*(NPTS-1))
C --------------- Loop on arms
      DO 3 K=1,2
      DO 1 I=1,3
      IF(K.EQ.2)U(I)=UU(I)
      IF(K.EQ.1)U(I)=UL(I)
      CURC(I)=U(I)
    1 CONTINUE
C --------------- Loop on arm
      DO 2 I=1,NPTS
      T=ARI*(I-1)
      CUR=SIN(PKC*(AL/2.-T))*(-1.)**K/3.
C ---------- Simpson's rule weights
      IF(I.GT.1.AND.I.LT.NPTS)THEN
      IF(MOD(I-1,2).EQ.1)CUR=CUR*4.
      IF(MOD(I-1,2).EQ.0)CUR=CUR*2.
      ENDIF
      CALL VLINC(1.,FD,T,U,XS)
      CALL NFPATR(XC,BLOCKN,XB,XS,EFIELD,HFIELD)
    2 SS=SS+CCDOT(EFIELD,CURC)*CUR*ARI
    3 CONTINUE
C --------------- Find magnitude of currents at inputs to dipoles
      CUR1=SIN(AL*PKC/2.)
      CUR2=SIN(ALC*PKC/2.)
      Z12=-SS/CUR1/CUR2
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VGREJF(VR,VT,VP,XS,PK,CUR,ETHETA,EPHI)
C
C  Far field Vector Green's Function
C
C  Vector Green's function between source current density: J
C  and electric field: E when multiplied by -j(2*pi*frequency)*mu
C  Vector Green's function between source current magnetic density: M
C  and the magnetic field: H when multiplied by -j(2*Pi*freq*epsilon)
C
C  VR(3)    Radial unit vector
C  VT(3)    Theta directed unit vector
C  VP(3)    Phi directed unit vector
C  XS(3)    Position of current element
C  PK       Propagation constant = 2*Pi/wavelength
C  CUR(3)   Rectangular coordinates of current density (complex)
C
C  ETHETA   Theta component of electric (magnetic) field
C  EPHI     Phi component of electric (magnetic) field
C
      DIMENSION VR(3),VT(3),VP(3),XS(3)
      COMPLEX CUR(3),CONP,ETHETA,EPHI
      DATA FPI/12.5663706/
      PHASE=PK*DOT(VR,XS)
      CONP=CMPLX(COS(PHASE),SIN(PHASE))/FPI
C ---------------- Field components from currents
      ETHETA=(CUR(1)*VT(1)+CUR(2)*VT(2)+CUR(3)*VT(3))*CONP
      EPHI=(CUR(1)*VP(1)+CUR(2)*VP(2)+CUR(3)*VP(3))*CONP
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VGREJN(XF,XS,PK,CUR,E)
C
C  Radiative Near field Vector Green's Function
C
C  Vector Green's function between source current density: J
C  and electric field: E when multiplied by -j(2*pi*frequency)*mu
C  Vector Green's function between source current magnetic density: M
C  and the magnetic field: H when multiplied by -j(2*Pi*freq*epsilon)
C
C  XF(3)    Field point (units must match PK)
C  XS(3)    Source point (units must match PK)
C  PK       Propagation constant = 2*Pi/wavelength
C  CUR(3)   Rectangular coordinates of current (complex)
C           When summing in an integration, use current density times
C           area of the surface patch or current times length for a
C           filament.  Use meters**2 or meters and amps.
C
C  E(3)     Returned electric (magnetic) field rectangular coord.
C
      DIMENSION XF(3),XS(3),RR(3)
      COMPLEX CUR(3),E(3),CONP,COEF
      DATA FPI/12.5663706/
      R=0.
C ---------------- Find relative radius vector
      DO 1 I=1,3
      RR(I)=XF(I)-XS(I)
    1 R=R+RR(I)**2
      R=SQRT(R)
C ---------------- Normalize radius vector
      DO 2 I=1,3
    2 RR(I)=RR(I)/R
      COEF=RR(1)*CUR(1)+RR(2)*CUR(2)+RR(3)*CUR(3)
      PHASE=PK*R
      CONP=CMPLX(COS(PHASE),-SIN(PHASE))/FPI/R
C ---------------- Field components from currents
      DO 3 I=1,3
    3 E(I)=(CUR(I)-RR(I)*COEF)*CONP
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VGRHJF(VR,VT,VP,XS,PK,CUR,HTHETA,HPHI)
C
C  Far field Vector Green's Function
C
C  Vector Green's function between source current density: J
C  and magnetic field: H  or
C  Vector Green's function between source current magnetic density: M
C  and the electric field: E when multiplied by -1
C
C  VR(3)    Radial unit vector
C  VT(3)    Theta directed unit vector
C  VP(3)    Phi directed unit vector
C  XS(3)    Position of current element
C  PK       Propagation constant = 2*Pi/wavelength
C  CUR(3)   Rectangular coordinates of current density (complex)
C
C  HTHETA   Theta component of magnetic (electric) field
C  HPHI     Phi component of magnetic (electric) field
C
      DIMENSION VR(3),VT(3),VP(3),XS(3)
      COMPLEX CUR(3),CONP,HTHETA,HPHI
      DATA FPI/12.5663706/
      PHASE=PK*DOT(XS,VR)
      CONP=-CMPLX(0.,PK)*CMPLX(COS(PHASE),SIN(PHASE))/FPI
C ---------------- Field components from currents
      HTHETA=(CUR(1)*VP(1)+CUR(2)*VP(2)+CUR(3)*VP(3))*CONP
      HPHI=-(CUR(1)*VT(1)+CUR(2)*VT(2)+CUR(3)*VT(3))*CONP
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VGRHJN(XF,XS,PK,CUR,H)
C
C  Radiative Near field Vector Green's Function
C
C  Vector Green's function between source current density: J
C  and magnetic field: H
C  Vector Green's function between source current magnetic density: M
C  and the electric field: E when multiplied by -1
C
C  XF(3)    Field point (units must match PK)
C  XS(3)    Source point (units must match PK)
C  PK       Propagation constant = 2*Pi/wavelength
C  CUR(3)   Rectangular coordinates of current (complex)
C           When summing in an integration, use current density times
C           area of the surface patch or current times length for a
C           filament.  Use meters**2 or meters and amps.
C
C  H(3)     Returned magnetic (-electric) field rectangular coord.
C
      DIMENSION XF(3),XS(3),RR(3)
      COMPLEX CUR(3),H(3),CONP
      DATA FPI/12.5663706/
      R=0.
C ---------------- Find relative radius vector
      DO 1 I=1,3
      RR(I)=XF(I)-XS(I)
    1 R=R+RR(I)**2
      R=SQRT(R)
C ---------------- Normalize radius vector
      DO 2 I=1,3
    2 RR(I)=RR(I)/R
      PHASE=PK*R
      CONP=CMPLX(0.,PK)*CMPLX(COS(PHASE),-SIN(PHASE))/FPI/R
C ---------------- Field components from currents
      CALL VCROSS(RR,CUR,H)
      DO 3 I=1,3
    3 H(I)=-CONP*H(I)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VLINC(A,V1,B,V2,VC)
C
C  Linear combination of two vectors
C
C  VC = A (scalar) * V1 (vector) + B (scalar) * V2 (vector)
C
      DIMENSION V1(3),V2(3),VC(3)
      DO1I=1,3
    1 VC(I)=A*V1(I)+B*V2(I)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VSLCMG(FREQ,FD,AL,WIDL,UU,UL,NPTS,CURR,ICAV,LUNIT,YIN)
C
C  Current multiplier for Vee slot and Input Admittance
C
C  FREQ    Frequency (GHz)
C  FD(3)   Feed point (m)
C  AL      Length of slot (sum of both arms) (m)
C  WIDL    Width of slot
C  UU(3)   Direction of unit vector of upper arm
C  UL(3)   Direction of unit vector of lower arm
C  NPTS    Number of points along each arm
C  CURR    Multiplier on current magnitude (for mutual = 1)
C  ICAV    0 - Radiates on both sides, 1 Cavity behind
C  LUNIT   Logical unit of file for currents
C
      COMPLEX YIN
      DIMENSION FD(3),UU(3),UL(3),FDI(3)
      DATA CC/.2997925/,PI/3.14159265/
C ------------- Find currents on single slot
      CURR=1.
      ALC=AL
      CALL VSLCUR(FREQ,FD,AL,UU,UL,NPTS,CURR,LUNIT)
C ------------- Load into currents common
      CALL CURCOM(LUNIT)
      FDI(1)=FD(1)
      FDI(2)=FD(2)+WIDL
      FDI(3)=FD(3)
C ------------- Find self impedance
      CALL VSLMUC(FDI,AL,ALC,UU,UL,NPTS,YIN)
      CURR=1./SQRT(REAL(YIN)*SIN(PI*AL*FREQ/CC))
      IF(ICAV.EQ.1)THEN
      YIN=YIN/2.
      CURR=CURR*2.
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
C
C  Note fewer currents are needed for pattern calculations than for the
C  self impedance.  The currents file can be reinitialized VSLCUR with
C  fewer points but with CURR from this routine to normalize power to
C  1 watt.
C
      END



      SUBROUTINE VSLCUR(FREQ,FD,AL,UU,UL,NPTT,CURR,LUNIT)
C
C  Currents file for Vee Slot (built in Simpson's rule integration)
C
C  FREQ    Frequency (GHz)
C  FD(3)   Feed point (m)
C  AL	   Length of slot (sum of both arms) (m)
C  UU(3)   Direction of unit vector of upper arm
C  UL(3)   Direction of unit vector of lower arm
C  NPTT    Number of points along each arm
C  CURR    Multiplier on current magnitude (for mutual = 1)
C  LUNIT   Logical unit of file for currents
C
      DIMENSION FREC(19),FD(3),UU(3),UL(3),U(3)
      INTEGER*4 IBUF(19)
      COMPLEX CURM(3)
      EQUIVALENCE (IBUF(3),PK),(FREC(14),CURM(1))
      DATA CC/.2997925/,PI/3.141592654/
      WAVEL=CC/FREQ
      PK=2.*PI/WAVEL
C --------- Round points up to odd for Simpson's rule
      NPTS=NPTT
      IF(MOD(NPTS,2).EQ.0)NPTS=NPTS+1
      IBUF(1)=2*NPTS
      IBUF(2)=2
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      KREC=1
      AI=AL/(2.*(NPTS-1))
      CURC=CURR/3.
C ---------- Loop on arms
      DO 4 K=1,2
      DO 1 I=1,3
      IF(K.EQ.1)U(I)=UU(I)
      IF(K.EQ.2)U(I)=UL(I)
    1 CONTINUE
C ---------- Loop on points along slot
      DO 3 I=1,NPTS
      T=(I-1)*AI
      CALL VLINC(1.,FD,T,U,FREC)
      CUR=-SIN(PK*(AL/2.-T))*CURC*AI*(-1.)**K
C ---------- Simpson's rule weights
      IF(I.GT.1.AND.I.LT.NPTS)THEN
      IF(MOD(I-1,2).EQ.1)CUR=CUR*4.
      IF(MOD(I-1,2).EQ.0)CUR=CUR*2.
      ENDIF
C ---------- Normal currents including Simpson's weights
      DO 2 J=1,3
    2 CURM(J)=U(J)*CUR
      KREC=KREC+1
    3 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    4 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE VSLMUC(FD,AL,ALC,UU,UL,NPTT,Y12)
C
C  Mutual coupling between Vee Slot and Currents File with slot
C  (built in Simpson's rule integration)
C
C  FD(3)    Location of Vee slot
C  AL	    Length of slot (sum of arms) (m)
C  ALC	    Length of slot coupling to
C  UU(3)    Unit vector in direction of upper arm
C  UL(3)    Unit vector in direction of lower arm
C  NPTT	    Number of points
C  Y12	    Mutual admittance
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMPLEX SS,EFIELD(3),HFIELD(3),Y12,CURC(3),CCDOT
      DIMENSION FD(3),XC(3),XS(3),UU(3),UL(3),U(3),XB(1)
      EXTERNAL BLOCKN
      DATA XC/0.,0.,0./
      SS=0.
C --------- Round points up to odd for Simpson's rule
      NPTS=NPTT
      IF(MOD(NPTS,2).EQ.0)NPTS=NPTS+1
      ARI=AL/(2.*(NPTS-1))
C --------------- Loop on arms
      DO 3 K=1,2
      DO 1 I=1,3
      IF(K.EQ.2)U(I)=UU(I)
      IF(K.EQ.1)U(I)=UL(I)
      CURC(I)=U(I)
    1 CONTINUE
C --------------- Loop on arm
      DO 2 I=1,NPTS
      T=ARI*(I-1)
      CUR=SIN(PKC*(AL/2.-T))*(-1.)**K/3.
C ---------- Simpson's rule weights
      IF(I.GT.1.AND.I.LT.NPTS)THEN
      IF(MOD(I-1,2).EQ.1)CUR=CUR*4.
      IF(MOD(I-1,2).EQ.0)CUR=CUR*2.
      ENDIF
      CALL VLINC(1.,FD,T,U,XS)
      CALL NFPATR(XC,BLOCKN,XB,XS,EFIELD,HFIELD)
    2 SS=SS+CCDOT(HFIELD,CURC)*CUR*ARI
    3 CONTINUE
C --------------- Find magnitude of currents at inputs to slots
      CUR1=SIN(AL*PKC/2.)
      CUR2=SIN(ALC*PKC/2.)
      Y12=-SS/CUR1/CUR2
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END



      SUBROUTINE ZRES(Z,ZS,ZL,R,RA,TRANS,TA,ZIN)
C
C  Response of Z matrix
C
C  Z(4)    2 x 2 Z matrix
C  ZS, ZL  Source, Load impedances
C  R	   Reflection coefficient magnitude
C  RA	   Reflection coefficient phase (deg)
C  TRANS   Transmission dB
C  TA	   Transmission phase (deg)
C  ZIN	   Input impedance
C
      COMPLEX Z(4),ZS,ZL,ZIN,B1
      ZIN=Z(1)-Z(2)*Z(3)/(ZL+Z(4))
      B1=(ZIN-ZS)/(ZIN+ZS)
      R=CABS(B1)
      RA=57.29578*ATAN2(AIMAG(B1),REAL(B1))
      B1=ZL*Z(3)/((Z(1)+ZS)*(Z(4)+ZL)-Z(2)*Z(3))
      TA=57.29578*ATAN2(AIMAG(B1),REAL(B1))
      TRANS=10.*ALOG10(4.*REAL(ZS)*REAL(ZL)*CABS(B1/ZL)**2)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
